% Auto-generated chapter 36 for tirmidhi
% Hadiths in this chapter: 111

\hadithdefcmd{tirmidhi}{2304}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، وَسُوَيْدُ بْنُ نَصْرٍ، قَالَ صَالِحٌ حَدَّثَنَا وَقَالَ، سُوَيْدٌ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نِعْمَتَانِ مَغْبُونٌ فِيهِمَا كَثِيرٌ مِنَ النَّاسِ الصِّحَّةُ وَالْفَرَاغُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ ‏.‏ وَقَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَاهُ غَيْرُ وَاحِدٍ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ فَرَفَعُوهُ وَأَوْقَفَهُ بَعْضُهُمْ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ ‏.‏\hadithno{2304}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"Two favors that many of the people squander are health and free time}}
\hadithdefcmd{tirmidhi}{2305}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ الْبَصْرِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ أَبِي طَارِقٍ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَأْخُذُ عَنِّي هَؤُلاَءِ الْكَلِمَاتِ فَيَعْمَلُ بِهِنَّ أَوْ يُعَلِّمُ مَنْ يَعْمَلُ بِهِنَّ ‏"‏ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ فَقُلْتُ أَنَا يَا رَسُولَ اللَّهِ فَأَخَذَ بِيَدِي فَعَدَّ خَمْسًا وَقَالَ ‏"‏ اتَّقِ الْمَحَارِمَ تَكُنْ أَعْبَدَ النَّاسِ وَارْضَ بِمَا قَسَمَ اللَّهُ لَكَ تَكُنْ أَغْنَى النَّاسِ وَأَحْسِنْ إِلَى جَارِكَ تَكُنْ مُؤْمِنًا وَأَحِبَّ لِلنَّاسِ مَا تُحِبُّ لِنَفْسِكَ تَكُنْ مُسْلِمًا وَلاَ تُكْثِرِ الضَّحِكَ فَإِنَّ كَثْرَةَ الضَّحِكِ تُمِيتُ الْقَلْبَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ جَعْفَرِ بْنِ سُلَيْمَانَ ‏.‏ وَالْحَسَنُ لَمْ يَسْمَعْ مِنْ أَبِي هُرَيْرَةَ شَيْئًا هَكَذَا رُوِيَ عَنْ أَيُّوبَ وَيُونُسَ بْنِ عُبَيْدٍ وَعَلِيِّ بْنِ زَيْدٍ قَالُوا لَمْ يَسْمَعِ الْحَسَنُ مِنْ أَبِي هُرَيْرَةَ ‏.‏ وَرَوَى أَبُو عُبَيْدَةَ النَّاجِيُّ عَنِ الْحَسَنِ هَذَا الْحَدِيثَ قَوْلَهُ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2305}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Al-Hasan narrated from Abu Hurairah that the Messenger of Allah (s.a.w) said:"Who will take these statements from me, so that he may act upon them, or teach one who will act upon them?" So Abu Hurairah said: "I said: 'I shall O Messenger of Allah!' So he (s.a.w) took my hand and enumerated five (things), he said: "Be on guard against the unlawful and you shall be the most worshiping among the people, be satisfied with what Allah has alloted for you and you shall be the richest of the people, be kind to your neighbor and you shall be a believer, love for the people what you love for yourself and you shall be a Muslim. And do not laugh too much, for indeed increased laughter kills the heart}}
\hadithdefcmd{tirmidhi}{2306}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، عَنْ مُحَرَّرِ بْنِ هَارُونَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا بِالأَعْمَالِ سَبْعًا هَلْ تَنْظُرُونَ إِلاَّ فَقْرًا مُنْسِيًا أَوْ غِنًى مُطْغِيًا أَوْ مَرَضًا مُفْسِدًا أَوْ هَرَمًا مُفَنِّدًا أَوْ مَوْتًا مُجْهِزًا أَوِ الدَّجَّالَ فَشَرُّ غَائِبٍ يُنْتَظَرُ أَوِ السَّاعَةَ فَالسَّاعَةُ أَدْهَى وَأَمَرُّ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ إِلاَّ مِنْ حَدِيثِ مُحَرَّرِ بْنِ هَارُونَ وَقَدْ رَوَى بِشْرُ بْنُ عُمَرَ وَغَيْرُهُ عَنْ مُحَرَّرِ بْنِ هَارُونَ هَذَا ‏.‏ وَقَدْ رَوَى مَعْمَرٌ هَذَا الْحَدِيثَ عَمَّنْ سَمِعَ سَعِيدًا الْمَقْبُرِيَّ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَقَالَ تَنْتَظِرُونَ ‏.‏\hadithno{2306}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah, may Allah be pleased with him, narrated that the Messenger of Allah (s.a.w) said:"Race to do works against seven. Are you waiting but for overwhelming poverty, or distracting richness, or debilitating illness, or babbling senility, or sudden death, or the Dajjal, so that hidden evil is what is awaited, or the Hour? The Hour is more calamitous and more bitter." (Daif)}}
\hadithdefcmd{tirmidhi}{2307}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَكْثِرُوا ذِكْرَ هَاذِمِ اللَّذَّاتِ ‏"‏ ‏.‏ يَعْنِي الْمَوْتَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2307}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Increase in remembrance of the severer of pleasures." Meaning death}}
\hadithdefcmd{tirmidhi}{2308}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بَحِيرٍ، أَنَّهُ سَمِعَ هَانِئًا، مَوْلَى عُثْمَانَ قَالَ كَانَ عُثْمَانُ إِذَا وَقَفَ عَلَى قَبْرٍ بَكَى حَتَّى يَبُلَّ لِحْيَتَهُ فَقِيلَ لَهُ تُذْكَرُ الْجَنَّةُ وَالنَّارُ فَلاَ تَبْكِي وَتَبْكِي مِنْ هَذَا فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْقَبْرَ أَوَّلُ مَنَازِلِ الآخِرَةِ فَإِنْ نَجَا مِنْهُ فَمَا بَعْدَهُ أَيْسَرُ مِنْهُ وَإِنْ لَمْ يَنْجُ مِنْهُ فَمَا بَعْدَهُ أَشَدُّ مِنْهُ ‏"‏ ‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا رَأَيْتُ مَنْظَرًا قَطُّ إِلاَّ وَالْقَبْرُ أَفْظَعُ مِنْهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ هِشَامِ بْنِ يُوسُفَ ‏.‏\hadithno{2308}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hani' the freed slave of 'Uthman said:When 'Uthman would stop at a grave he would cry until his beard was soaked (in tears). It was said to him: 'The Paradise and the Fire were mentioned and you did not cry, yet you cry because of this?' So he said: 'Indeed the Messenger of Allah said: "Indeed the grave is the first stage among the stages of the Hereafter. So if one is saved from it, then what comes after it is easier than it. And if one is not saved from it, then what comes after it is worse than it." And the Messenger of Allah said: "I have not seen any sight except that the grave is more horrible than it}}
\hadithdefcmd{tirmidhi}{2309}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ وَأَنَسٍ وَأَبِي مُوسَى ‏.‏ قَالَ حَدِيثُ عُبَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2309}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubadah bin As-Samit narrated that the Messenger of Allah (s.a.w) said:"Whoever loves to meet Allah, Allah loves to meet him. Whoever is averse to meeting Allah, Allah is averse to meeting him}}
\hadithdefcmd{tirmidhi}{2310}{حَدَّثَنَا أَبُو الأَشْعَثِ، أَحْمَدُ بْنُ الْمِقْدَامِ الْعِجْلِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الطُّفَاوِيُّ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏:‏ ‏(‏ وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ ‏)‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا صَفِيَّةُ بِنْتَ عَبْدِ الْمُطَّلِبِ يَا فَاطِمَةُ بِنْتَ مُحَمَّدٍ يَا بَنِي عَبْدِ الْمُطَّلِبِ إِنِّي لاَ أَمْلِكُ لَكُمْ مِنَ اللَّهِ شَيْئًا سَلُونِي مِنْ مَالِي مَا شِئْتُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي مُوسَى وَابْنِ عَبَّاسٍ ‏.‏ قَالَ حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ هَكَذَا رَوَى بَعْضُهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ نَحْوَ هَذَا وَرَوَى بَعْضُهُمْ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً لَمْ يَذْكُرْ فِيهِ عَنْ عَائِشَةَ ‏.‏\hadithno{2310}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"When this Ayah was revealed: And warn your near kindred....(26:214), the Messenger of Allah (s.a.w) said: "O Safiyyah bint 'Abdul-Muttalib! O Fatimah bint Muhammed! O Banu 'Abdul-Muttalib! I have no authority on your behalf over Allah for anything. Ask me for whatever you want of my wealth}}
\hadithdefcmd{tirmidhi}{2311}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ الْمَسْعُودِيِّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَلِجُ النَّارَ رَجُلٌ بَكَى مِنْ خَشْيَةِ اللَّهِ حَتَّى يَعُودَ اللَّبَنُ فِي الضَّرْعِ وَلاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي رَيْحَانَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ هُوَ مَوْلَى آلِ طَلْحَةَ وَهُوَ مَدَنِيٌّ ثِقَةٌ رَوَى عَنْهُ شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ ‏.‏\hadithno{2311}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said :"A man who cries out of fearing Allah, will not be put into the Fire until milk returns to the udder; and dust raised in the cause of Allah and the smoke of Jahannam will not be gathered together." [He said:] There are narrations on this topic from Abu Raihanah and Ibn 'Abbas. [He said:] This Hadith is [Hasan] Sahih. Muhammad bin 'Abdur-Rahman is the Mawla of the family of Talbah, and he is from Al-Madinah, and trustworthy. Shu'bah and Sufyan Ath-Thawri reported from him}}
\hadithdefcmd{tirmidhi}{2312}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ إِبْرَاهِيمَ بْنِ الْمُهَاجِرِ، عَنْ مُجَاهِدٍ، عَنْ مُوَرِّقٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي أَرَى مَا لاَ تَرَوْنَ وَأَسْمَعُ مَا لاَ تَسْمَعُونَ أَطَّتِ السَّمَاءُ وَحُقَّ لَهَا أَنْ تَئِطَّ مَا فِيهَا مَوْضِعُ أَرْبَعِ أَصَابِعَ إِلاَّ وَمَلَكٌ وَاضِعٌ جَبْهَتَهُ سَاجِدًا لِلَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا وَمَا تَلَذَّذْتُمْ بِالنِّسَاءِ عَلَى الْفُرُشِ وَلَخَرَجْتُمْ إِلَى الصُّعُدَاتِ تَجْأَرُونَ إِلَى اللَّهِ ‏"‏ ‏.‏ لَوَدِدْتُ أَنِّي كُنْتُ شَجَرَةً تُعْضَدُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَأَنَسٍ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَيُرْوَى مِنْ غَيْرِ هَذَا الْوَجْهِ أَنَّ أَبَا ذَرٍّ قَالَ لَوَدِدْتُ أَنِّي كُنْتُ شَجَرَةً تُعْضَدُ ‏.‏\hadithno{2312}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dharr narrated that the Messenger of Allah (s.a.w) said:"Indeed I see what you do not see, and I hear what you do not hear. The Heavens moan, and they have the right to moan. There is no spot, the size of four fingers in them, except that there is an angel placing his forehead in it, prostrating to Allah. By Allah! If you knew what I know, then you would laugh little and you would cry much. And you would not taste the pleasures of your women in the beds, and you would go out beseeching Allah. And I wish that I was but a felled tree." [Abu 'Eisa said:] There are narrations on this topic from 'Aishah, Abu Hurairah, Ibn 'Abbas, and Anas. [He said:] This Hadith is Hasan Gharib. It has been related through routes other than this, that Abu Dharr said: "I wish that I was a felled tree." And it has been related from Abu Dharr in Mawquf form}}
\hadithdefcmd{tirmidhi}{2313}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ الْفَلاَّسُ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2313}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"If you knew what I know, then you would laugh little and you would cry much}}
\hadithdefcmd{tirmidhi}{2314}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الرَّجُلَ لَيَتَكَلَّمُ بِالْكَلِمَةِ لاَ يَرَى بِهَا بَأْسًا يَهْوِي بِهَا سَبْعِينَ خَرِيفًا فِي النَّارِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2314}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Indeed a man may utter a statement that he does not see any harm in, but for which he will fall seventy autumns in the Fire}}
\hadithdefcmd{tirmidhi}{2315}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَيْلٌ لِلَّذِي يُحَدِّثُ بِالْحَدِيثِ لِيُضْحِكَ بِهِ الْقَوْمَ فَيَكْذِبُ وَيْلٌ لَهُ وَيْلٌ لَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2315}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim narrated from his father, from his grandfather that Prophet (s.a.w) said:"Woe to the one who talks about something to make the people laugh, in which he lies. Woe to him! Woe to him}}
\hadithdefcmd{tirmidhi}{2316}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الْجَبَّارِ الْبَغْدَادِيُّ، حَدَّثَنَاَ عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ تُوُفِّيَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ يَعْنِي رَجُلٌ أَبْشِرْ بِالْجَنَّةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَلاَ تَدْرِي فَلَعَلَّهُ تَكَلَّمَ فِيمَا لاَ يَعْنِيهِ أَوْ بَخِلَ بِمَا لاَ يَنْقُصُهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2316}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that a man among his companions was dying so he said- meaning a man said to him:"Glad tidings of Paradise." To which the Messenger of Allah (s.a.w) said: "You do not know. Perhaps he spoke of what did not concern him or he was greedy with that which would not decrease him}}
\hadithdefcmd{tirmidhi}{2317}{حَدَّثَنَا أَحْمَدُ بْنُ نَصْرٍ النَّيْسَابُورِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو مُسْهِرٍ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ اللَّهِ بْنِ سَمَاعَةَ، عَنِ الأَوْزَاعِيِّ، عَنْ قُرَّةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِنْ حُسْنِ إِسْلاَمِ الْمَرْءِ تَرْكُهُ مَا لاَ يَعْنِيهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2317}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Indeed among the excellence of a person's Islam is that he leaves what does not concern him}}
\hadithdefcmd{tirmidhi}{2318}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ حُسْنِ إِسْلاَمِ الْمَرْءِ تَرْكَهُ مَا لاَ يَعْنِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ مِنْ أَصْحَابِ الزُّهْرِيِّ عَنِ الزُّهْرِيِّ عَنْ عَلِيِّ بْنِ حُسَيْنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ مَالِكٍ مُرْسَلاً وَهَذَا عِنْدَنَا أَصَحُّ مِنْ حَدِيثِ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَعَلِيُّ بْنُ حُسَيْنٍ لَمْ يُدْرِكْ عَلِيَّ بْنَ أَبِي طَالِبٍ ‏.‏\hadithno{2318}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Al-Husain narrated that the Messenger of Allah (s.a.w) said:"Surely, of the excellence of a person's Islam is that he leaves what does not concern him}}
\hadithdefcmd{tirmidhi}{2319}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ سَمِعْتُ بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ، صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَحَدَكُمْ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ رِضْوَانِ اللَّهِ مَا يَظُنُّ أَنْ تَبْلُغَ مَا بَلَغَتْ فَيَكْتُبُ اللَّهُ لَهُ بِهَا رِضْوَانَهُ إِلَى يَوْمِ يَلْقَاهُ وَإِنَّ أَحَدَكُمْ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ سَخَطِ اللَّهِ مَا يَظُنُّ أَنْ تَبْلُغَ مَا بَلَغَتْ فَيَكْتُبُ اللَّهُ عَلَيْهِ بِهَا سَخَطَهُ إِلَى يَوْمِ يَلْقَاهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ حَبِيبَةَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو نَحْوَ هَذَا قَالُوا عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِيهِ عَنْ جَدِّهِ عَنْ بِلاَلِ بْنِ الْحَارِثِ ‏.‏ وَرَوَى هَذَا الْحَدِيثَ مَالِكٌ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِيهِ عَنْ بِلاَلِ بْنِ الْحَارِثِ وَلَمْ يَذْكُرْ فِيهِ عَنْ جَدِّهِ ‏.‏\hadithno{2319}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammed bin 'Amr narrated from his father, from his grandfather who said:"I heard Bilal bin Al-Harith Al Muzani, the Companion of the Messenger of Allah (s.a.w) saying: 'I heard the Messenger of Allah (s.a.w) saying: "Indeed one of you says a statement pleasing to Allah, not realizing that you have achieved what you have achieved. Then for it, Allah writes for him His pleasure until the Day of Meeting Him. And one of you says a statement angering Allah, not realizing that you have achieved what you have achieved. Then for it, Allah writes for him His anger until the Day of Meeting with Him}}
\hadithdefcmd{tirmidhi}{2320}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ سُلَيْمَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَتِ الدُّنْيَا تَعْدِلُ عِنْدَ اللَّهِ جَنَاحَ بَعُوضَةٍ مَا سَقَى كَافِرًا مِنْهَا شَرْبَةَ مَاءٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2320}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Sahl bin Sa'd narrated that the Messenger of Allah (s.a.w) said:"If the world to Allah was equal to a mosquito's wing, then He would not allow the disbeliever to have a sip of water from it}}
\hadithdefcmd{tirmidhi}{2321}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُجَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُسْتَوْرِدِ بْنِ شَدَّادٍ، قَالَ كُنْتُ مَعَ الرَّكْبِ الَّذِينَ وَقَفُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى السَّخْلَةِ الْمَيِّتَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَرَوْنَ هَذِهِ هَانَتْ عَلَى أَهْلِهَا حِينَ أَلْقَوْهَا ‏"‏ ‏.‏ قَالُوا مِنْ هَوَانِهَا أَلْقَوْهَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَالدُّنْيَا أَهْوَنُ عَلَى اللَّهِ مِنْ هَذِهِ عَلَى أَهْلِهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْمُسْتَوْرِدِ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2321}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-Mustawrid bin Shaddad said:"I was with the caravan of those who stopped with the Messenger of Allah (s.a.w) at a dead lamb. The Messenger of Allah (s.a.w) said: 'Do you think that this was insignificant to its owners when they threw it away?' They said:'Yes! It is because of its insignificance that they threw it away O Messenger of Allah!' He said: 'The world is more insignificant to Allah than this to its owners}}
\hadithdefcmd{tirmidhi}{2322}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُكْتِبُ، حَدَّثَنَا عَلِيُّ بْنُ ثَابِتٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ، قَالَ سَمِعْتُ عَطَاءَ بْنَ قُرَّةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ ضَمْرَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَلاَ إِنَّ الدُّنْيَا مَلْعُونَةٌ مَلْعُونٌ مَا فِيهَا إِلاَّ ذِكْرَ اللَّهِ وَمَا وَالاَهُ وَعَالِمًا أَوْ مُتَعَلِّمًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2322}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Lo! Indeed the world is cursed. What is in it is cursed, except for remembrance of Allah, what is conducive to that, the knowledgeable person and the learning person}}
\hadithdefcmd{tirmidhi}{2323}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، حَدَّثَنَا قَيْسُ بْنُ أَبِي حَازِمٍ، قَالَ سَمِعْتُ مُسْتَوْرِدًا، أَخَا بَنِي فِهْرٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا الدُّنْيَا فِي الآخِرَةِ إِلاَّ مِثْلُ مَا يَجْعَلُ أَحَدُكُمْ إِصْبَعَهُ فِي الْيَمِّ فَلْيَنْظُرْ بِمَاذَا يَرْجِعُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ يُكْنَى أَبَا عَبْدِ اللَّهِ وَوَالِدُ قَيْسٍ أَبُو حَازِمٍ اسْمُهُ عَبْدُ بْنُ عَوْفٍ وَهُوَ مِنَ الصَّحَابَةِ ‏.‏\hadithno{2323}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Qa'is bin Abi Hazim said:I heard Mustawrid, a member of Banu Fihr, saying: The Messenger of Allah (s.a.w) said: "The world compared to the Hereafter is but like what one of you gets when placing his finger into the sea, so look at what you draw from it}}
\hadithdefcmd{tirmidhi}{2324}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الدُّنْيَا سِجْنُ الْمُؤْمِنِ وَجَنَّةُ الْكَافِرِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2324}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The world is a prison for the believer and Paradise for the disbeliever}}
\hadithdefcmd{tirmidhi}{2325}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عُبَادَةُ بْنُ مُسْلِمٍ، حَدَّثَنَا يُونُسُ بْنُ خَبَّابٍ، عَنْ سَعِيدٍ الطَّائِيِّ أَبِي الْبَخْتَرِيِّ، أَنَّهُ قَالَ حَدَّثَنِي أَبُو كَبْشَةَ الأَنْمَارِيُّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ ثَلاَثَةٌ أُقْسِمُ عَلَيْهِنَّ وَأُحَدِّثُكُمْ حَدِيثًا فَاحْفَظُوهُ ‏"‏ ‏.‏ قَالَ ‏"‏ مَا نَقَصَ مَالُ عَبْدٍ مِنْ صَدَقَةٍ وَلاَ ظُلِمَ عَبْدٌ مَظْلِمَةً فَصَبَرَ عَلَيْهَا إِلاَّ زَادَهُ اللَّهُ عِزًّا وَلاَ فَتَحَ عَبْدٌ بَابَ مَسْأَلَةٍ إِلاَّ فَتَحَ اللَّهُ عَلَيْهِ بَابَ فَقْرٍ أَوْ كَلِمَةً نَحْوَهَا وَأُحَدِّثُكُمْ حَدِيثًا فَاحْفَظُوهُ قَالَ ‏"‏ إِنَّمَا الدُّنْيَا لأَرْبَعَةِ نَفَرٍ عَبْدٍ رَزَقَهُ اللَّهُ مَالاً وَعِلْمًا فَهُوَ يَتَّقِي فِيهِ رَبَّهُ وَيَصِلُ فِيهِ رَحِمَهُ وَيَعْلَمُ لِلَّهِ فِيهِ حَقًّا فَهَذَا بِأَفْضَلِ الْمَنَازِلِ وَعَبْدٍ رَزَقَهُ اللَّهُ عِلْمًا وَلَمْ يَرْزُقْهُ مَالاً فَهُوَ صَادِقُ النِّيَّةِ يَقُولُ لَوْ أَنَّ لِي مَالاً لَعَمِلْتُ بِعَمَلِ فُلاَنٍ فَهُوَ بِنِيَّتِهِ فَأَجْرُهُمَا سَوَاءٌ وَعَبْدٍ رَزَقَهُ اللَّهُ مَالاً وَلَمْ يَرْزُقْهُ عِلْمًا فَهُوَ يَخْبِطُ فِي مَالِهِ بِغَيْرِ عِلْمٍ لاَ يَتَّقِي فِيهِ رَبَّهُ وَلاَ يَصِلُ فِيهِ رَحِمَهُ وَلاَ يَعْلَمُ لِلَّهِ فِيهِ حَقًّا فَهَذَا بِأَخْبَثِ الْمَنَازِلِ وَعَبْدٍ لَمْ يَرْزُقْهُ اللَّهُ مَالاً وَلاَ عِلْمًا فَهُوَ يَقُولُ لَوْ أَنَّ لِي مَالاً لَعَمِلْتُ فِيهِ بِعَمَلِ فُلاَنٍ فَهُوَ بِنِيَّتِهِ فَوِزْرُهُمَا سَوَاءٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2325}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Kabshah Al-Anmari narrated that the Messenger of Allah (s.a.w) said:"There are three things for which I swear and narrate to you about, so remember it." He said: "The wealth of a slave (of Allah) shall not be decreased by charity, no slave (of Allah) suffers injustice and is patient with it except that Allah adds to his honor; no slave (of Allah) opens up a door to begging except that Allah opens a door for him to poverty"- or a statement similar- "And I shall narrate to you a narration, so remember it." He said: "The world is only for four persons: A slave whom Allah provides with wealth and knowledge, so he has Taqwa of his Lord with it, nurtures the ties of kinship with it, and he knows that Allah has a right in it. So this is the most virtuous rank. And a slave whom Allah provides with knowledge, but He does not provide with wealth. So he has a truthful intent, saying: 'If I had wealth, then I would do the deeds of so-and-so with it.' He has his intention, so their rewards are the same. And a slave whom Allah provides with wealth, but He does not provide him with knowledge. [So he] spends his wealth rashly without knowledge, nor having Taqwa of his Lord, nor nurturing the ties of kinship, and he does not know that Allah has a right in it. So this is the most despicable rank. And a slave whom Allah does not provide with wealth nor knowledge, so he says: 'If I had wealth, then I would do the deeds of so-and-so with it.' He has his intention, so their sin is the same}}
\hadithdefcmd{tirmidhi}{2326}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ بَشِيرٍ أَبِي إِسْمَاعِيلَ، عَنْ سَيَّارٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَزَلَتْ بِهِ فَاقَةٌ فَأَنْزَلَهَا بِالنَّاسِ لَمْ تُسَدَّ فَاقَتُهُ وَمَنْ نَزَلَتْ بِهِ فَاقَةٌ فَأَنْزَلَهَا بِاللَّهِ فَيُوشِكُ اللَّهُ لَهُ بِرِزْقٍ عَاجِلٍ أَوْ آجِلٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2326}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Mas'ud narrated that the Messenger of Allah (s.a.w) said:"Whoever suffers from destitution and he beseeches the people for it, his destitution shall not end. And whoever suffers from destitution and he beseeches Allah for it, Allah will send provisions to him, sooner or later}}
\hadithdefcmd{tirmidhi}{2327}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ جَاءَ مُعَاوِيَةُ إِلَى أَبِي هَاشِمِ بْنِ عُتْبَةَ وَهُوَ مَرِيضٌ يَعُودُهُ فَقَالَ يَا خَالُ مَا يُبْكِيكَ أَوَجَعٌ يُشْئِزُكَ أَمْ حِرْصٌ عَلَى الدُّنْيَا قَالَ كُلٌّ لاَ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَهِدَ إِلَىَّ عَهْدًا لَمْ آخُذْ بِهِ قَالَ ‏ "‏ إِنَّمَا يَكْفِيكَ مِنْ جَمْعِ الْمَالِ خَادِمٌ وَمَرْكَبٌ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ وَأَجِدُنِي الْيَوْمَ قَدْ جَمَعْتُ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى زَائِدَةُ وَعَبِيدَةُ بْنُ حُمَيْدٍ عَنْ مَنْصُورٍ عَنْ أَبِي وَائِلٍ عَنْ سَمُرَةَ بْنِ سَهْمٍ قَالَ دَخَلَ مُعَاوِيَةُ عَلَى أَبِي هَاشِمٍ فَذَكَرَ نَحْوَهُ ‏.‏ وَفِي الْبَابِ عَنْ بُرَيْدَةَ الأَسْلَمِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2327}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Wail narrated:"Mu'awiyah came to Abu Hashim bin 'Uthbah to visit him when he was ill (and dying). He said: 'O Uncle! Why do you cry? Is it from the pangs of death or desire for this world?' He said: 'Neither of these. But the Messenger of Allah (s.a.w) had commissioned me with an obligation that I did not abide by. He (s.a.w) said: "It suffices you to gather the wealth of a servant or a rider in the cause of Allah." And (it is only) today I find that I have gathered it}}
\hadithdefcmd{tirmidhi}{2328}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ شِمْرِ بْنِ عَطِيَّةَ، عَنِ الْمُغِيرَةِ بْنِ سَعْدِ بْنِ الأَخْرَمِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَتَّخِذُوا الضَّيْعَةَ فَتَرْغَبُوا فِي الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2328}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah [bin Mas'ud] narrated that the Messenger of Allah (s.a.w) said:"Do not take to the estate, such that you become desirous of the world}}
\hadithdefcmd{tirmidhi}{2329}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، أَنَّ أَعْرَابِيًّا، قَالَ يَا رَسُولَ اللَّهِ مَنْ خَيْرُ النَّاسِ قَالَ ‏ "‏ مَنْ طَالَ عُمُرُهُ وَحَسُنَ عَمَلُهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2329}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Busr narrated that a Bedouin said:"O Messenger of Allah! Who is the best of the people?" He said: "He whose life is long and his deeds are good."There are narrations on this topic from Abu Hurairah and Jabir}}
\hadithdefcmd{tirmidhi}{2330}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ خَيْرٌ قَالَ ‏"‏ مَنْ طَالَ عُمُرُهُ وَحَسُنَ عَمَلُهُ ‏"‏ ‏.‏ قَالَ فَأَىُّ النَّاسِ شَرٌّ قَالَ ‏"‏ مَنْ طَالَ عُمُرُهُ وَسَاءَ عَمَلُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2330}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdur-Rahman bin Abi-Bakrah narrated from his father that a man said:"O Messenger of Allah! Which of the people is the best?" He said: "He whose life is long and his deeds are good." He said: "Then which of the people is the worst?" He said: "He whose life is long and his deeds are bad}}
\hadithdefcmd{tirmidhi}{2331}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنْ كَامِلٍ أَبِي الْعَلاَءِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عُمُرُ أُمَّتِي مِنْ سِتِّينَ سَنَةً إِلَى سَبْعِينَ سَنَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2331}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The lifespan for my Ummah is from sixty years to seventy [years]}}
\hadithdefcmd{tirmidhi}{2332}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ الْعُمَرِيُّ، عَنْ سَعْدِ بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَتَقَارَبَ الزَّمَانُ فَتَكُونُ السَّنَةُ كَالشَّهْرِ وَالشَّهْرُ كَالْجُمُعَةِ وَتَكُونُ الْجُمُعَةُ كَالْيَوْمِ وَيَكُونُ الْيَوْمُ كَالسَّاعَةِ وَتَكُونُ السَّاعَةُ كَالضَّرْمَةِ بِالنَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَسَعْدُ بْنُ سَعِيدٍ هُوَ أَخُو يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏\hadithno{2332}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that the Allah's Messenger (s.a.w) said:"The hour shall not be established until time is constricted, and the year is like a month, a month is like the week, and the week is like the day, and the day is like the hour, and the hour is like the flare of the fire}}
\hadithdefcmd{tirmidhi}{2333}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنْكَبِي فَقَالَ ‏"‏ كُنْ فِي الدُّنْيَا كَأَنَّكَ غَرِيبٌ أَوْ عَابِرُ سَبِيلٍ وَعُدَّ نَفْسَكَ فِي أَهْلِ الْقُبُورِ ‏"‏ ‏.‏ فَقَالَ لِي ابْنُ عُمَرَ إِذَا أَصْبَحْتَ فَلاَ تُحَدِّثْ نَفْسَكَ بِالْمَسَاءِ وَإِذَا أَمْسَيْتَ فَلاَ تُحَدِّثْ نَفْسَكَ بِالصَّبَاحِ وَخُذْ مِنْ صِحَّتِكَ قَبْلَ سَقَمِكَ وَمِنْ حَيَاتِكَ قَبْلَ مَوْتِكَ فَإِنَّكَ لاَ تَدْرِي يَا عَبْدَ اللَّهِ مَا اسْمُكَ غَدًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى هَذَا الْحَدِيثَ الأَعْمَشُ عَنْ مُجَاهِدٍ عَنِ ابْنِ عُمَرَ نَحْوَهُ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ لَيْثٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2333}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Mujahid narrated that Ibn 'Umar said:"The Messenger of Allah (s.a.w) grabbed me on part of my body and said: 'Be in the world like a stranger or a passerby, and count yourself among the inhabitants of the grave.'" Ibn 'Umar said to me: "When you wake up in the morning, then do not concern yourself with the evening. And when you reach the evening, then do not concern yourself with the morning. Take from your health before your illness, and from your life before your death, for indeed O slave of Allah! You do not know what your description shall be tomorrow." (sahih)}}
\hadithdefcmd{tirmidhi}{2334}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا ابْنُ آدَمَ وَهَذَا أَجَلُهُ ‏"‏ ‏.‏ وَوَضَعَ يَدَهُ عِنْدَ قَفَاهُ ثُمَّ بَسَطَهَا فَقَالَ ‏"‏ وَثَمَّ أَمَلُهُ وَثَمَّ أَمَلُهُ وَثَمَّ أَمَلُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏\hadithno{2334}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik narrated that that the Messenger of Allah(s.a.w) said:"This is the son of Adam, and this is his life-span." And he placed his hand at the (height of the) nape of his neck, then he extended it (higher) and said:" From there is what is hoped for, from there is what is hoped for}}
\hadithdefcmd{tirmidhi}{2335}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي السَّفَرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ مَرَّ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نُعَالِجُ خُصًّا لَنَا فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ فَقُلْنَا قَدْ وَهَى فَنَحْنُ نُصْلِحُهُ ‏.‏ قَالَ ‏"‏ مَا أُرَى الأَمْرَ إِلاَّ أَعْجَلَ مِنْ ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو السَّفَرِ اسْمُهُ سَعِيدُ بْنُ يُحْمِدَ وَيُقَالُ ابْنُ أَحْمَدَ الثَّوْرِيُّ ‏.‏\hadithno{2335}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu As-Safr narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah (s.a.w) passed by us while we were repairing a hut of ours, so he said: 'What is this?' We said:"It has become weak, so we are repairing it.' He said: 'I do not think but that the matter (of life) is more in fleeting than that}}
\hadithdefcmd{tirmidhi}{2336}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا الْحَسَنُ بْنُ سَوَّارٍ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ جُبَيْرِ بْنِ نُفَيْرِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ كَعْبِ بْنِ عِيَاضٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ لِكُلِّ أُمَّةٍ فِتْنَةً وَفِتْنَةُ أُمَّتِي الْمَالُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ مُعَاوِيَةَ بْنِ صَالِحٍ ‏.‏\hadithno{2336}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ka'b bin 'Iyad narrated that the Prophet (s.a.w) said:"Indeed there is a fitnah for every Ummah, and the Fitnah for my Ummah is wealth}}
\hadithdefcmd{tirmidhi}{2337}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ لاِبْنِ آدَمَ وَادِيًا مِنْ ذَهَبٍ لأَحَبَّ أَنْ يَكُونَ لَهُ ثَانِيًا وَلاَ يَمْلأُ فَاهُ إِلاَّ التُّرَابُ وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ وَأَبِي سَعِيدٍ وَعَائِشَةَ وَابْنِ الزُّبَيْرِ وَأَبِي وَاقِدٍ وَجَابِرٍ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2337}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah said:"If the Son of Adam had a valley of gold, then he would still like to have a second . And nothing fills his mouth but dust, Allah turns to whoever repents}}
\hadithdefcmd{tirmidhi}{2338}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ قَلْبُ الشَّيْخِ شَابٌّ عَلَى حُبِّ اثْنَتَيْنِ طُولُ الْحَيَاةِ وَكَثْرَةُ الْمَالِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2338}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"The heart of an old man remains young because of love for two things: Long life , and much wealth}}
\hadithdefcmd{tirmidhi}{2339}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَهْرَمُ ابْنُ آدَمَ وَيَشِبُّ مِنْهُ اثْنَتَانِ الْحِرْصُ عَلَى الْعُمُرِ وَالْحِرْصُ عَلَى الْمَالِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2339}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated that the Prophet (s.a.w) said:"The Son Of Adan grows old, but two things keep him young: Desire for life and desire for wealth}}
\hadithdefcmd{tirmidhi}{2340}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا عَمْرُو بْنُ وَاقِدٍ، حَدَّثَنَا يُونُسُ بْنُ حَلْبَسٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الزَّهَادَةُ فِي الدُّنْيَا لَيْسَتْ بِتَحْرِيمِ الْحَلاَلِ وَلاَ إِضَاعَةِ الْمَالِ وَلَكِنَّ الزَّهَادَةَ فِي الدُّنْيَا أَنْ لاَ تَكُونَ بِمَا فِي يَدَيْكَ أَوْثَقَ مِمَّا فِي يَدَىِ اللَّهِ وَأَنْ تَكُونَ فِي ثَوَابِ الْمُصِيبَةِ إِذَا أَنْتَ أُصِبْتَ بِهَا أَرْغَبَ فِيهَا لَوْ أَنَّهَا أُبْقِيَتْ لَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو إِدْرِيسَ الْخَوْلاَنِيُّ اسْمُهُ عَائِذُ اللَّهِ بْنُ عَبْدِ اللَّهِ ‏.‏ وَعَمْرُو بْنُ وَاقِدٍ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{2340}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Dharr narrated that the Prophet (s.a.w) said:"Abstinence in the world is not by prohibiting (oneself) the lawful nor by neglecting wealth , but abstinence in the world is that you not hold more firmly to what is in your hand than to what is in the hand of Allah, and that you be more hopeful of the rewards that come with an affliction that you may suffer if it remain with you}}
\hadithdefcmd{tirmidhi}{2341}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا حُرَيْثُ بْنُ السَّائِبِ، قَالَ سَمِعْتُ الْحَسَنَ، يَقُولُ حَدَّثَنِي حُمْرَانُ بْنُ أَبَانَ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ لاِبْنِ آدَمَ حَقٌّ فِي سِوَى هَذِهِ الْخِصَالِ بَيْتٌ يَسْكُنُهُ وَثَوْبٌ يُوَارِي عَوْرَتَهُ وَجِلْفُ الْخُبْزِ وَالْمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ حَدِيثُ الْحُرَيْثِ بْنِ السَّائِبِ ‏.‏ وَسَمِعْتُ أَبَا دَاوُدَ سُلَيْمَانَ بْنَ سَلْمٍ الْبَلْخِيَّ يَقُولُ قَالَ النَّضْرُ بْنُ شُمَيْلٍ جِلْفُ الْخُبْزِ يَعْنِي لَيْسَ مَعَهُ إِدَامٌ ‏.‏\hadithno{2341}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Uthman bin 'Affan narrated that the Prophet (s.a.w) said:"There is no right for the son of Adam in other than these things: A house which he lives in, a garment which covers his nakedness, and Jilf (a piece of bread) and water}}
\hadithdefcmd{tirmidhi}{2342}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ أَبِيهِ، أَنَّهُ انْتَهَى إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏:‏ ‏(‏أَلْهَاكُمُ التَّكَاثُرُ ‏)‏ قَالَ ‏"‏ يَقُولُ ابْنُ آدَمَ مَالِي مَالِي وَهَلْ لَكَ مِنْ مَالِكَ إِلاَّ مَا تَصَدَّقْتَ فَأَمْضَيْتَ أَوْ أَكَلْتَ فَأَفْنَيْتَ أَوْ لَبِسْتَ فَأَبْلَيْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2342}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Mutarrif narrated from his father, that he met up with the Prophet (s.a.w) while he was saying:"The mutual increase diverts you". He (s.a.w) said: "The son of Adam says:'My wealth, my wealth, but is there something for you from your wealth besides what you give in charity that remains, or you eat which perishes, or what you wear that grows worn?}}
\hadithdefcmd{tirmidhi}{2343}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، - هُوَ الْيَمَامِيُّ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا شَدَّادُ بْنُ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا ابْنَ آدَمَ إِنَّكَ إِنْ تَبْذُلِ الْفَضْلَ خَيْرٌ لَكَ وَإِنْ تُمْسِكْهُ شَرٌّ لَكَ وَلاَ تُلاَمُ عَلَى كَفَافٍ وَابْدَأْ بِمَنْ تَعُولُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَشَدَّادُ بْنُ عَبْدِ اللَّهِ يُكْنَى أَبَا عَمَّارٍ ‏.‏\hadithno{2343}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Umamah narrated that the Prophet (s.a.w) said:"O son of Adam! If you give your surplus it is better for you, and if you keep it, it is worse for you, but there is no harm with what is sufficient. And begin(the giving) with your dependents, and the upper hand (giving) is better than the lower hand (receiving)}}
\hadithdefcmd{tirmidhi}{2344}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنْ بَكْرِ بْنِ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ هُبَيْرَةَ، عَنْ أَبِي تَمِيمٍ الْجَيْشَانِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّكُمْ كُنْتُمْ تَوَكَّلُونَ عَلَى اللَّهِ حَقَّ تَوَكُّلِهِ لَرُزِقْتُمْ كَمَا تُرْزَقُ الطَّيْرُ تَغْدُو خِمَاصًا وَتَرُوحُ بِطَانًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو تَمِيمٍ الْجَيْشَانِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ مَالِكٍ ‏.‏\hadithno{2344}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umar bin Al-Khattab narrated that the Messenger of Allah (s.a.w) said:"If you were to rely upon Allah with the required reliance, then He would provide for you just as a bird is provided for, it goes out in the morning empty, and returns full}}
\hadithdefcmd{tirmidhi}{2345}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ أَخَوَانِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَكَانَ أَحَدُهُمَا يَأْتِي النَّبِيَّ صلى الله عليه وسلم وَالآخَرُ يَحْتَرِفُ فَشَكَا الْمُحْتَرِفُ أَخَاهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَعَلَّكَ تُرْزَقُ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2345}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik narrated:"There were two brothers during the time of the Messenger of Allah (s.a.w). One of them used to come to the prophet (s.a.w), and the other had some business. The businessman among them complained to the Prophet (s.a.w) about his brother, so he said:'Perhaps you are provided for because of him}}
\hadithdefcmd{tirmidhi}{2346}{حَدَّثَنَا عَمْرُو بْنُ مَالِكٍ وَمَحْمُودُ بْنُ خِدَاشٍ الْبَغْدَادِيُّ قَالَا حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي شُمَيْلَةَ الْأَنْصَارِيُّ عَنْ سَلَمَةَ بْنِ عُبَيْدِ اللَّهِ بْنِ مِحْصَنٍ الْخَطْمِيِّ عَنْ أَبِيهِ وَكَانَتْ لَهُ صُحْبَةٌ قَالَ قَالَ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ مَنْ أَصْبَحَ مِنْكُمْ آمِنًا فِي سِرْبِهِ مُعَافًى فِي جَسَدِهِ عِنْدَهُ قُوتُ يَوْمِهِ فَكَأَنَّمَا حِيزَتْ لَهُ الدُّنْيَا قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لَا نَعْرِفُهُ إِلَّا مِنْ حَدِيثِ مَرْوَانَ بْنِ مُعَاوِيَةَ وَحِيزَتْ جُمِعَتْ حَدَّثَنَا بِذَلِكَ مُحَمَّدُ بْنُ إِسْمَعِيلَ حَدَّثَنَا الْحُمَيْدِيُّ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ نَحْوَهُ وَفِي الْبَاب عَنْ أَبِي الدَّرْدَاءِ\hadithno{2346}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Salamah bin 'Ubaidullah bin Mihsan Al-Khatmi narrated from his father -and he was a Companion- who said:"The Messenger of Allah (s.a.w) said: "Whoever among you wakes up in the morning secured in his dwelling, healthy in his body, having his food for the day,then it is as if the world has been gathered for him}}
\hadithdefcmd{tirmidhi}{2347}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَغْبَطَ أَوْلِيَائِي عِنْدِي لَمُؤْمِنٌ خَفِيفُ الْحَاذِ ذُو حَظٍّ مِنَ الصَّلاَةِ أَحْسَنَ عِبَادَةَ رَبِّهِ وَأَطَاعَهُ فِي السِّرِّ وَكَانَ غَامِضًا فِي النَّاسِ لاَ يُشَارُ إِلَيْهِ بِالأَصَابِعِ وَكَانَ رِزْقُهُ كَفَافًا فَصَبَرَ عَلَى ذَلِكَ ‏"‏ ‏.‏ ثُمَّ نَفَضَ بِيَدِهِ فَقَالَ ‏"‏ عُجِّلَتْ مَنِيَّتُهُ قَلَّتْ بَوَاكِيهِ قَلَّ تُرَاثُهُ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عَرَضَ عَلَىَّ رَبِّي لِيَجْعَلَ لِي بَطْحَاءَ مَكَّةَ ذَهَبًا قُلْتُ لاَ يَا رَبِّ وَلَكِنْ أَشْبَعُ يَوْمًا وَأَجُوعُ يَوْمًا أَوْ قَالَ ثَلاَثًا أَوْ نَحْوَ هَذَا فَإِذَا جُعْتُ تَضَرَّعْتُ إِلَيْكَ وَذَكَرْتُكَ وَإِذَا شَبِعْتُ شَكَرْتُكَ وَحَمِدْتُكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَفِي الْبَابِ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ ‏.‏ وَالْقَاسِمُ هَذَا هُوَ ابْنُ عَبْدِ الرَّحْمَنِ وَيُكْنَى أَبَا عَبْدِ الرَّحْمَنِ وَهُوَ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ خَالِدِ بْنِ يَزِيدَ بْنِ مُعَاوِيَةَ وَهُوَ شَامِيٌّ ثِقَةٌ وَعَلِيُّ بْنُ يَزِيدَ ضَعِيفُ الْحَدِيثِ وَيُكْنَى أَبَا عَبْدِ الْمَلِكِ ‏.‏\hadithno{2347}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah narrated that the Prophet (s.a.w) said:"Indeed the best of my friends to me is the one of meager conditions, whose share is in Salat, worshipping his Lord well and obeying him (even) in private. He is obscure among the people such that the fingers are not pointed towards him. His provisions are only what is sufficient and he is patient with that." Then he tapped with his fingers and said: "His death comes quickly, his mourners are few, and his inheritance is little."With this (the above), chain it is narrated that the Prophet (s.a.w) said: "My Lord presented to me, that He would make the valley of Makkah into gold for me, I said: 'No O Lord! But being filled for a day and hungry for a day"-or he said: "three days" or something like that- "So when I am hungry, I would beseech You and remember You, and when I am full I would be grateful to You and praise You}}
\hadithdefcmd{tirmidhi}{2348}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ شُرَحْبِيلَ بْنِ شَرِيكٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَدْ أَفْلَحَ مَنْ أَسْلَمَ وَكَانَ رِزْقُهُ كَفَافًا وَقَنَّعَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2348}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Amr narrated that the Messenger of Allah (s.a.w) said:"He has succeeded who accepts Islam, and is provided with what is sufficient and is made content by Allah}}
\hadithdefcmd{tirmidhi}{2349}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، أَخْبَرَنَا حَيْوَةُ بْنُ شُرَيْحٍ، أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّ أَبَا عَلِيٍّ، عَمْرَو بْنَ مَالِكٍ الْجَنْبِيَّ أَخْبَرَهُ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ طُوبَى لِمَنْ هُدِيَ إِلَى الإِسْلاَمِ وَكَانَ عَيْشُهُ كَفَافًا وَقَنِعَ ‏"‏ ‏.‏ قَالَ وَأَبُو هَانِئٍ اسْمُهُ حُمَيْدُ بْنُ هَانِئٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2349}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Fadalah bin 'Ubaid narrated that he heard the Messenger of Allah (s.a.w) saying:"Glad tidings to whoever is guided to Islam, his livelihood was sufficient and he was satisfied}}
\hadithdefcmd{tirmidhi}{2350}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ نَبْهَانَ بْنِ صَفْوَانَ الثَّقَفِيُّ الْبَصْرِيُّ، حَدَّثَنَا رَوْحُ بْنُ أَسْلَمَ، حَدَّثَنَا شَدَّادٌ أَبُو طَلْحَةَ الرَّاسِبِيُّ، عَنْ أَبِي الْوَازِعِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ وَاللَّهِ إِنِّي لأُحِبُّكَ ‏.‏ فَقَالَ ‏"‏ انْظُرْ مَاذَا تَقُولُ ‏"‏ ‏.‏ قَالَ وَاللَّهِ إِنِّي لأُحِبُّكَ ‏.‏ فَقَالَ ‏"‏ انْظُرْ مَاذَا تَقُولُ ‏"‏ ‏.‏ قَالَ وَاللَّهِ إِنِّي لأُحِبُّكَ ‏.‏ ثَلاَثَ مَرَّاتٍ فَقَالَ ‏"‏ إِنْ كُنْتَ تُحِبُّنِي فَأَعِدَّ لِلْفَقْرِ تِجْفَافًا فَإِنَّ الْفَقْرَ أَسْرَعُ إِلَى مَنْ يُحِبُّنِي مِنَ السَّيْلِ إِلَى مُنْتَهَاهُ ‏"‏ ‏.‏ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبِي، عَنْ شَدَّادٍ أَبِي طَلْحَةَ، نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو الْوَازِعِ الرَّاسِبِيُّ اسْمُهُ جَابِرُ بْنُ عَمْرٍو وَهُوَ بَصْرِيٌّ ‏.‏\hadithno{2350}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Maghaffal said:"A man said to the Prophet (s.a.w): 'O Messenger of Allah! By Allah! Indeed I love you!' So he said: 'Consider what you say.' He said: 'By Allah! I indeed love you!' Three times. He said: 'If you do love me, then prepare and arm yourself against poverty. For indeed poverty comes faster upon whoever loves me than the flood to its destination}}
\hadithdefcmd{tirmidhi}{2351}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْبَصْرِيُّ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، عَنِ الأَعْمَشِ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فُقَرَاءُ الْمُهَاجِرِينَ يَدْخُلُونَ الْجَنَّةَ قَبْلَ أَغْنِيَائِهِمْ بِخَمْسِمِائَةِ سَنَةٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2351}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated that the Messenger of Allah (s.a.w) said:"The poor Muhajirin will enter Paradise before the rich among them by five hundred years}}
\hadithdefcmd{tirmidhi}{2352}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلٍ الْكُوفِيُّ، حَدَّثَنَا ثَابِتُ بْنُ مُحَمَّدٍ الْعَابِدُ الْكُوفِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ النُّعْمَانِ اللَّيْثِيُّ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اللَّهُمَّ أَحْيِنِي مِسْكِينًا وَأَمِتْنِي مِسْكِينًا وَاحْشُرْنِي فِي زُمْرَةِ الْمَسَاكِينِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ لِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّهُمْ يَدْخُلُونَ الْجَنَّةَ قَبْلَ أَغْنِيَائِهِمْ بِأَرْبَعِينَ خَرِيفًا يَا عَائِشَةُ لاَ تَرُدِّي الْمِسْكِينَ وَلَوْ بِشِقِّ تَمْرَةٍ يَا عَائِشَةُ أَحِبِّي الْمَسَاكِينَ وَقَرِّبِيهِمْ فَإِنَّ اللَّهَ يُقَرِّبُكِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{2352}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Messenger of Allah (s.a.w) said:"O Allah! Cause me to live needy, and cause me to die needy and gather me in the group of the needy on the Day of Resurrection." 'Aishah said: "Why O Messenger of Allah?" He said: "Indeed they enter Paradise before their rich by forty autumns. O 'Aishah! Do not turn away the needy even if with a piece of date. O 'Aishah! Love the needy and be near them, for indeed Allah will make you near on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{2353}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَدْخُلُ الْفُقَرَاءُ الْجَنَّةَ قَبْلَ الأَغْنِيَاءِ بِخَمْسِمِائَةِ عَامٍ نِصْفِ يَوْمٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2353}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The poor are admitted into Paradise before the rich, by five hundres years, (i.e.) half a day}}
\hadithdefcmd{tirmidhi}{2354}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَدْخُلُ فُقَرَاءُ الْمُسْلِمِينَ الْجَنَّةَ قَبْلَ أَغْنِيَائِهِمْ بِنِصْفِ يَوْمٍ وَهُوَ خَمْسُمِائَةِ عَامٍ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2354}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"The poor Muslims are admitted into Paradise before their rich by half a day. And that is five hundred years}}
\hadithdefcmd{tirmidhi}{2355}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ عَمْرِو بْنِ جَابِرٍ الْحَضْرَمِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَدْخُلُ فُقَرَاءُ الْمُسْلِمِينَ الْجَنَّةَ قَبْلَ أَغْنِيَائِهِمْ بِأَرْبَعِينَ خَرِيفًا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2355}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin 'Abdullah narrated that the Messenger of Allah (s.a.w) said:"The poor Muslims are admitted into Paradise before their rich by forty autumns}}
\hadithdefcmd{tirmidhi}{2356}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ الْمُهَلَّبِيُّ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَدَعَتْ لِي بِطَعَامٍ وَقَالَتْ مَا أَشْبَعُ مِنْ طَعَامٍ فَأَشَاءُ أَنْ أَبْكِيَ إِلاَّ بَكَيْتُ ‏.‏ قَالَ قُلْتُ لِمَ قَالَتْ أَذْكُرُ الْحَالَ الَّتِي فَارَقَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم الدُّنْيَا وَاللَّهِ مَا شَبِعَ مِنْ خُبْزٍ وَلَحْمٍ مَرَّتَيْنِ فِي يَوْمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2356}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Masruq said:"I entered upon 'Aishah and she invited me to eat. She said: 'Whenever I eat my fill of food I want to cry and begin crying.' He said: "I said : 'Why?' She said: 'I remember the circumstances under which the Messenger of Allah (s.a.w) parted from the world. By Allah! He would not eat his fill of bread and meat twice in a day}}
\hadithdefcmd{tirmidhi}{2357}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، يُحَدِّثُ عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ خُبْزِ شَعِيرٍ يَوْمَيْنِ مُتَتَابِعَيْنِ حَتَّى قُبِضَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2357}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"The Messenger of Allah (s.a.w) did not eat his fill of barley bread on two consecutive days until he was taken (died)}}
\hadithdefcmd{tirmidhi}{2358}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا الْمُحَارِبِيُّ، حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا شَبِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ ثَلاَثًا تِبَاعًا مِنْ خُبْزِ الْبُرِّ حَتَّى فَارَقَ الدُّنْيَا ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2358}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated:"Neither the Messenger of Allah (s.a.w) nor his family, ate their fill of wheat bread for three consecutive days until he parted the world}}
\hadithdefcmd{tirmidhi}{2359}{حَدَّثَنَا عَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا حَرِيزُ بْنُ عُثْمَانَ، عَنْ سُلَيْمِ بْنِ عَامِرٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ مَا كَانَ يَفْضُلُ عَنْ أَهْلِ، بَيْتِ النَّبِيِّ صلى الله عليه وسلم خُبْزُ الشَّعِيرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَيَحْيَى بْنُ أَبِي بُكَيْرٍ هَذَا كُوفِيٌّ وَأَبُو بُكَيْرٍ وَالِدُ يَحْيَى رَوَى لَهُ سُفْيَانُ الثَّوْرِيُّ وَيَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ بُكَيْرٍ مِصْرِيٌّ صَاحِبُ اللَّيْثِ ‏.‏\hadithno{2359}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Umamah narrated:"There was never a surplus of barley bread for the inhabitants of the house of the Messenger of Allah (s.a.w)}}
\hadithdefcmd{tirmidhi}{2360}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَبِيتُ اللَّيَالِيَ الْمُتَتَابِعَةَ طَاوِيًا وَأَهْلُهُ لاَ يَجِدُونَ عَشَاءً وَكَانَ أَكْثَرُ خُبْزِهِمْ خُبْزَ الشَّعِيرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2360}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Abbas said:" The Messenger of Allah (s.a.w) would spend many consecutive nights and his family did not have supper, and most of the time their bread was barley bread}}
\hadithdefcmd{tirmidhi}{2361}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اجْعَلْ رِزْقَ آلِ مُحَمَّدٍ قُوتًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2361}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated the the Messenger of Allah (s.a.w) said:"O Allah! Make the sustenance of Muhammad's family nourishing}}
\hadithdefcmd{tirmidhi}{2362}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَدَّخِرُ شَيْئًا لِغَدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ جَعْفَرِ بْنِ سُلَيْمَانَ عَنْ ثَابِتٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{2362}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas narrated:"The Prophet (s.a.w) would not store anything for the morrow}}
\hadithdefcmd{tirmidhi}{2363}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ مَا أَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى خِوَانٍ وَلاَ أَكَلَ خُبْزًا مُرَقَّقًا حَتَّى مَاتَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ سَعِيدِ بْنِ أَبِي عَرُوبَةَ ‏.‏\hadithno{2363}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas said:"The Messenger of Allah (s.a.w) never ate on a table, nor did he eat thin bread until he died}}
\hadithdefcmd{tirmidhi}{2364}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَخْبَرَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّهُ قِيلَ لَهُ أَكَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّقِيَّ يَعْنِي الْحُوَّارَى فَقَالَ سَهْلٌ مَا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم النَّقِيَّ حَتَّى لَقِيَ اللَّهَ ‏.‏ فَقِيلَ لَهُ هَلْ كَانَتْ لَكُمْ مَنَاخِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مَا كَانَتْ لَنَا مَنَاخِلُ ‏.‏ قِيلَ فَكَيْفَ كُنْتُمْ تَصْنَعُونَ بِالشَّعِيرِ قَالَ كُنَّا نَنْفُخُهُ فَيَطِيرُ مِنْهُ مَا طَارَ ثُمَّ نُثَرِّيهِ فَنَعْجِنُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ مَالِكُ بْنُ أَنَسٍ عَنْ أَبِي حَازِمٍ ‏.‏\hadithno{2364}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hazin narrated that Sahl bin Sa'd asked:"Did the Messenger of Allah (s.a.w) eat Naqi – meaning refined (flour)?” So Sahl said: “The Messenger of Allah (s.a.w) did not see Naqi until he met Allah.” It was said to him: “Did you have sifters during the time of the Messenger of Allah (s.a.w)?” He said: “There were no sifters for us.” They said: “How did you prepare the barley?”He said: “We would blow it so (the husk) would fly off of it, then we would add water so we could knead it.” (Hasan)}}
\hadithdefcmd{tirmidhi}{2365}{حَدَّثَنَا عُمَرُ بْنُ إِسْمَاعِيلَ بْنِ مُجَالِدِ بْنِ سَعِيدٍ، حَدَّثَنَا أَبِي، عَنْ بَيَانٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ إِنِّي لأَوَّلُ رَجُلٍ أَهْرَاقَ دَمًا فِي سَبِيلِ اللَّهِ وَإِنِّي لأَوَّلُ رَجُلٍ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ وَلَقَدْ رَأَيْتُنِي أَغْزُو فِي الْعِصَابَةِ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم مَا نَأْكُلُ إِلاَّ وَرَقَ الشَّجَرِ وَالْحُبُلَةِ حَتَّى إِنَّ أَحَدَنَا لَيَضَعُ كَمَا تَضَعُ الشَّاةُ أَوِ الْبَعِيرُ وَأَصْبَحَتْ بَنُو أَسَدٍ يُعَزِّرُونِي فِي الدِّينِ لَقَدْ خِبْتُ إِذًا وَضَلَّ عَمَلِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ بَيَانٍ ‏.‏\hadithno{2365}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Sa'd Bin Abi Waqqas said:"I was among the first men who spilled blood in Allah's cause, and I was among the first men to shoot an arrow in Allah's cause. I saw battles with troops of the Companions of Muhammad (s.a.w). We had nothing to eat except leaves of trees and Al-Hublah, such that one of us would leave droppings like the droppings of sheep and camels. Now Banu Asad have appeared wanting to instruct me in religion, ( then) I would be a loser and have wasted my efforts}}
\hadithdefcmd{tirmidhi}{2366}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، حَدَّثَنَا قَيْسٌ، قَالَ سَمِعْتُ سَعْدَ بْنَ مَالِكٍ، يَقُولُ إِنِّي أَوَّلُ رَجُلٍ مِنَ الْعَرَبِ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ وَلَقَدْ رَأَيْتُنَا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَا لَنَا طَعَامٌ إِلاَّ الْحُبُلَةَ وَهَذَا السَّمُرَ حَتَّى إِنَّ أَحَدَنَا لَيَضَعُ كَمَا تَضَعُ الشَّاةُ ثُمَّ أَصْبَحَتْ بَنُو أَسَدٍ يُعَزِّرُونِي فِي الدِّينِ لَقَدْ خِبْتُ إِذًا وَضَلَّ عَمَلِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عُتْبَةَ بْنِ غَزْوَانَ ‏.‏\hadithno{2366}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'd Bin Malik said:"I was the first man among the Arabs to shoot an arrow in Allah's cause. I saw that we battled along with the Messenger of Allah(s.a.w) and there was no food for us but Al-Hubla and this Samur, such that one of us would leave droppings like the droppings of a sheep. Then Banu Asad appeared wanting to instruct me in religion. I would be a loser and have wasted my efforts}}
\hadithdefcmd{tirmidhi}{2367}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ كُنَّا عِنْدَ أَبِي هُرَيْرَةَ وَعَلَيْهِ ثَوْبَانِ مُمَشَّقَانِ مِنْ كَتَّانٍ فَتَمَخَّطَ فِي أَحَدِهِمَا ثُمَّ قَالَ بَخٍ بَخٍ يَتَمَخَّطُ أَبُو هُرَيْرَةَ فِي الْكَتَّانِ لَقَدْ رَأَيْتُنِي وَإِنِّي لأَخِرُّ فِيمَا بَيْنَ مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَحُجْرَةِ عَائِشَةَ مِنَ الْجُوعِ مَغْشِيًّا عَلَىَّ فَيَجِيءُ الْجَائِي فَيَضَعُ رِجْلَهُ عَلَى عُنُقِي يُرَى أَنَّ بِيَ الْجُنُونَ وَمَا بِي جُنُونٌ وَمَا هُوَ إِلاَّ الْجُوعُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏ مِنْ هَذَا الْوَجْهِ\hadithno{2367}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Muhammad bin Sirin said:"We were with Abu Hurarirah and he was wearing two linen garments dyed with red ochre. He blew his nose in one of them and said: 'Excellent! Abu hurairah blows his nose in linens! I saw a time when I would pass out between the mimbar of the Messenger of Allah (s.a.w) and the dwelling of 'Aishah from overwhelming hunger. Someone came and placed his foot on my neck thinking that I was a mad man, but I was not crazy, It was nothing but hunger." (sahih)}}
\hadithdefcmd{tirmidhi}{2368}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّ أَبَا عَلِيٍّ، عَمْرَو بْنَ مَالِكٍ الْجَنْبِيَّ أَخْبَرَهُ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا صَلَّى بِالنَّاسِ يَخِرُّ رِجَالٌ مِنْ قَامَتِهِمْ فِي الصَّلاَةِ مِنَ الْخَصَاصَةِ وَهُمْ أَصْحَابُ الصُّفَّةِ حَتَّى تَقُولَ الأَعْرَابُ هَؤُلاَءِ مَجَانِينُ أَوْ مَجَانُونَ فَإِذَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم انْصَرَفَ إِلَيْهِمْ فَقَالَ ‏ "‏ لَوْ تَعْلَمُونَ مَا لَكُمْ عِنْدَ اللَّهِ لأَحْبَبْتُمْ أَنْ تَزْدَادُوا فَاقَةً وَحَاجَةً ‏"‏ ‏.‏ قَالَ فَضَالَةُ وَأَنَا يَوْمَئِذٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2368}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Fadalah bin 'Ubaid narrated that when the Messenger of Allah (s.a.w) would lead the people in Salat some men would collapse among them during the Salat due to hunger – they were among them Ashab As-suffah – such that a Bedouin would say :'These people are mad' or "possessed." So when the Messenger of Allah (s.a.w) finished the Salah, he turned to them and said: 'If you knew what was in store for you with Allah then you would love to be increased in poverty and need.'” Fadalah said: “And on that day, I was with the Messenger of Allah(s.a.w).” (Hasan)}}
\hadithdefcmd{tirmidhi}{2369}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شَيْبَانُ أَبُو مُعَاوِيَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فِي سَاعَةٍ لاَ يَخْرُجُ فِيهَا وَلاَ يَلْقَاهُ فِيهَا أَحَدٌ فَأَتَاهُ أَبُو بَكْرٍ فَقَالَ ‏"‏ مَا جَاءَ بِكَ يَا أَبَا بَكْرٍ ‏"‏ ‏.‏ فَقَالَ خَرَجْتُ أَلْقَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَنْظُرُ فِي وَجْهِهِ وَالتَّسْلِيمَ عَلَيْهِ ‏.‏ فَلَمْ يَلْبَثْ أَنْ جَاءَ عُمَرُ فَقَالَ ‏"‏ مَا جَاءَ بِكَ يَا عُمَرُ ‏"‏ ‏.‏ قَالَ الْجُوعُ يَا رَسُولَ اللَّهِ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَنَا قَدْ وَجَدْتُ بَعْضَ ذَلِكَ ‏"‏ ‏.‏ فَانْطَلَقُوا إِلَى مَنْزِلِ أَبِي الْهَيْثَمِ بْنِ التَّيِّهَانِ الأَنْصَارِيِّ وَكَانَ رَجُلاً كَثِيرَ النَّخْلِ وَالشَّاءِ وَلَمْ يَكُنْ لَهُ خَدَمٌ فَلَمْ يَجِدُوهُ فَقَالُوا لاِمْرَأَتِهِ أَيْنَ صَاحِبُكِ فَقَالَتِ انْطَلَقَ يَسْتَعْذِبُ لَنَا الْمَاءَ ‏.‏ فَلَمْ يَلْبَثُوا أَنْ جَاءَ أَبُو الْهَيْثَمِ بِقِرْبَةٍ يَزْعَبُهَا فَوَضَعَهَا ثُمَّ جَاءَ يَلْتَزِمُ النَّبِيَّ صلى الله عليه وسلم وَيُفَدِّيهِ بِأَبِيهِ وَأُمِّهِ ثُمَّ انْطَلَقَ بِهِمْ إِلَى حَدِيقَتِهِ فَبَسَطَ لَهُمْ بِسَاطًا ثُمَّ انْطَلَقَ إِلَى نَخْلَةٍ فَجَاءَ بِقِنْوٍ فَوَضَعَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَفَلاَ تَنَقَّيْتَ لَنَا مِنْ رُطَبِهِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَرَدْتُ أَنْ تَخْتَارُوا أَوْ قَالَ تَخَيَّرُوا مِنْ رُطَبِهِ وَبُسْرِهِ ‏.‏ فَأَكَلُوا وَشَرِبُوا مِنْ ذَلِكَ الْمَاءِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا وَالَّذِي نَفْسِي بِيَدِهِ مِنَ النَّعِيمِ الَّذِي تُسْأَلُونَ عَنْهُ يَوْمَ الْقِيَامَةِ ظِلٌّ بَارِدٌ وَرُطَبٌ طَيِّبٌ وَمَاءٌ بَارِدٌ ‏"‏ ‏.‏ فَانْطَلَقَ أَبُو الْهَيْثَمِ لِيَصْنَعَ لَهُمْ طَعَامًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تَذْبَحَنَّ ذَاتَ دَرٍّ ‏"‏ ‏.‏ قَالَ فَذَبَحَ لَهُمْ عَنَاقًا أَوْ جَدْيًا فَأَتَاهُمْ بِهَا فَأَكَلُوا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ خَادِمٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَإِذَا أَتَانَا سَبْىٌ فَائْتِنَا ‏"‏ ‏.‏ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِرَأْسَيْنِ لَيْسَ مَعَهُمَا ثَالِثٌ فَأَتَاهُ أَبُو الْهَيْثَمِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اخْتَرْ مِنْهُمَا ‏"‏ ‏.‏ فَقَالَ يَا نَبِيَّ اللَّهِ اخْتَرْ لِي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ الْمُسْتَشَارَ مُؤْتَمَنٌ خُذْ هَذَا فَإِنِّي رَأَيْتُهُ يُصَلِّي وَاسْتَوْصِ بِهِ مَعْرُوفًا ‏"‏ ‏.‏ فَانْطَلَقَ أَبُو الْهَيْثَمِ إِلَى امْرَأَتِهِ فَأَخْبَرَهَا بِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتِ امْرَأَتُهُ مَا أَنْتَ بِبَالِغٍ مَا قَالَ فِيهِ النَّبِيُّ صلى الله عليه وسلم إِلاَّ أَنْ تَعْتِقَهُ قَالَ فَهُوَ عَتِيقٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ لَمْ يَبْعَثْ نَبِيًّا وَلاَ خَلِيفَةً إِلاَّ وَلَهُ بِطَانَتَانِ بِطَانَةٌ تَأْمُرُهُ بِالْمَعْرُوفِ وَتَنْهَاهُ عَنِ الْمُنْكَرِ وَبِطَانَةٌ لاَ تَأْلُوهُ خَبَالاً وَمَنْ يُوقَ بِطَانَةَ السُّوءِ فَقَدْ وُقِيَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2369}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated :"The Prophet (s.a.w) went out during an hour in which he would normally not go out, nor meet with anyone. Then Abu Bakr came to him. So he said:"What brought you O Abu Bakr?" He said: "I came to meet the Messenger of Allah (s.a.w) and to look at his face, and to make sure he was safe. It was not long before 'Umar came. He said: "What has brought you O 'Umar ?" He said: "Hunger O Messenger of Allah!"He said: "I also experienced some of that" So they went to the home of Abu Al-Haitham At-Taiyyihan Al-Ansari. He was a man with many date-palms and sheep, but he had no servants so they did not find him there. They said to his wife: "Where is your companion?" She said: "He has gone to fetch us some good water." It was not long before Abu Al-Haitham came along hauling to a large water-skin which he put down. Then he came to hug the Prophet (s.a.w) and uttered that his father and mother should be ransomed for him. Then he went to grove of his and he spread out a mat for them. Then he went to a date-palm and returned with a cluster of dates which he put down. The prophet (s.a.w) said: "Why don't you select some ripe dates for us?" He said: "O Messenger of Allah(s.a.w)! I wanted you to select from the ripe dates and the unripe dates." So they ate and they drank from that water. The Messenger of Allah(s.a.w) said: "By the One in Whose Hand is my soul! This is among the favors which you shall be asked about on the Day of Judgement. Cool shade, tasty ripe dates, and cool water." Abu Al-Haitham left to prepare some food for them. The Prophet (s.a.w) said: "Do not slaughter one with milk." So he Slaughtered a small female or male goat and brought it to them so they could eat it. The Prophet (s.a.w) said: "Do you have any servants?" He said: "No." So he said: "Then if we get some captives we shall bring them for you." So (later) the Prophet (s.a.w) came with 2 males, there was no third among them and he brought them to Abu Al-Haitham. The Prophet (s.a.w) said: "Choose from them." He said: "O Prophet of Allah! Choose for me." So the Prophet (s.a.w) said: "Indeed the one consulted is entrusted. Take this one for I have seen him praying, and encourage him to do well." So Abu Al-Haitham went to his wife and informed her of what the Messenger of Allah (s.a.w) said. So his wife said: "You will not fulfill what the Prophet (s.a.w) said until you have freed him." So he said: "He is free." So the Prophet (s.a.w) said: "Indeed Allah has not send a Prophet nor made a Khalifah except that he has two groups of supporters, group ordering him to do good, and prohibiting him from evil and a group that never ceases spoiling his affairs. So whoever protected}}
\hadithdefcmd{tirmidhi}{2370}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمًا وَأَبُو بَكْرٍ وَعُمَرُ فَذَكَرَ نَحْوَ هَذَا الْحَدِيثِ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي هُرَيْرَةَ وَحَدِيثُ شَيْبَانَ أَتَمُّ مِنْ حَدِيثِ أَبِي عَوَانَةَ وَأَطْوَلُ ‏.‏ وَشَيْبَانُ ثِقَةٌ عِنْدَهُمْ صَاحِبُ كِتَابٍ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ أَيْضًا ‏.‏\hadithno{2370}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Salamah bin 'Abdur-Rahman narrated that:the Messenger of Allah(s.a.w) went out one day accompained by Abu Bakr and 'Umar. And he mentioned similar to Hadith( no 2369) in meaning, but he did not mention "from Abu Hurairah" in it}}
\hadithdefcmd{tirmidhi}{2371}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا سَيَّارُ بْنُ حَاتِمٍ، عَنْ سَهْلِ بْنِ أَسْلَمَ، عَنْ يَزِيدَ بْنِ أَبِي مَنْصُورٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي طَلْحَةَ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْجُوعَ وَرَفَعْنَا عَنْ بُطُونِنَا عَنْ حَجَرٍ حَجَرٍ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ حَجَرَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2371}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik narrated from Abu Talhah who said:"We complained to the Messenger of Allah(s.a.w) of hunger and we raised(our garments ) from our stomachs (exposing) a stone (on each of us). So the Messenger of Allah(s.a.w) raised (his garment exposing) two stones}}
\hadithdefcmd{tirmidhi}{2372}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ أَلَسْتُمْ فِي طَعَامٍ وَشَرَابٍ مَا شِئْتُمْ لَقَدْ رَأَيْتُ نَبِيَّكُمْ صلى الله عليه وسلم وَمَا يَجِدُ مِنَ الدَّقَلِ مَا يَمْلأُ بَطْنَهُ ‏.‏ قَالَ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى أَبُو عَوَانَةَ وَغَيْرُ وَاحِدٍ عَنْ سِمَاكِ بْنِ حَرْبٍ نَحْوَ حَدِيثِ أَبِي الأَحْوَصِ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ سِمَاكٍ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ عَنْ عُمَرَ ‏.‏\hadithno{2372}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Simak bin Harb said:"I heard An-Nu'man bin Bashir saying: 'Do you (people) not have what you wish of food and drink?' I have seen your Prophet and he did not have even enough daqal (dry dates) to fill his stomach}}
\hadithdefcmd{tirmidhi}{2373}{حَدَّثَنَا أَحْمَدُ بْنُ بُدَيْلِ بْنِ قُرَيْشٍ الْيَامِيُّ الْكُوفِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ الْغِنَى عَنْ كَثْرَةِ الْعَرَضِ وَلَكِنِ الْغِنَى غِنَى النَّفْسِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَصِينٍ اسْمُهُ عُثْمَانُ بْنُ عَاصِمٍ الأَسَدِيُّ ‏.‏\hadithno{2373}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Richness is not having many possessions, but richness is being content with oneself}}
\hadithdefcmd{tirmidhi}{2374}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي الْوَلِيدِ، قَالَ سَمِعْتُ خَوْلَةَ بِنْتَ قَيْسٍ، وَكَانَتْ، تَحْتَ حَمْزَةَ بْنِ عَبْدِ الْمُطَّلِبِ تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ مَنْ أَصَابَهُ بِحَقِّهِ بُورِكَ لَهُ فِيهِ وَرُبَّ مُتَخَوِّضٍ فِيمَا شَاءَتْ بِهِ نَفْسُهُ مِنْ مَالِ اللَّهِ وَرَسُولِهِ لَيْسَ لَهُ يَوْمَ الْقِيَامَةِ إِلاَّ النَّارُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْوَلِيدِ اسْمُهُ عُبَيْدُ سَنُوطَى\hadithno{2374}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Khawlah bint Qais, who was the wife of Hamzah bin 'Abdul-Muttalib narrated that the Messenger of Allah (s.a.w) said:"Indeed this wealth is green and sweet. Whoever gets what he deserves of it then he shall be blessed in it. And many a person who deals with what he wants for himself, from the wealth of Allah and His Messenger, gets nothing on the Day of Judgment but the Fire}}
\hadithdefcmd{tirmidhi}{2375}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لُعِنَ عَبْدُ الدِّينَارِ لُعِنَ عَبْدُ الدِّرْهَمِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا أَتَمَّ مِنْ هَذَا وَأَطْوَلَ ‏.‏\hadithno{2375}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Cursed be the slave of the Dinar, cursed be the slave of the Dirham}}
\hadithdefcmd{tirmidhi}{2376}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ الأَنْصَارِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا ذِئْبَانِ جَائِعَانِ أُرْسِلاَ فِي غَنَمٍ بِأَفْسَدَ لَهَا مِنْ حِرْصِ الْمَرْءِ عَلَى الْمَالِ وَالشَّرَفِ لِدِينِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى فِي هَذَا الْبَابِ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلاَ يَصِحُّ إِسْنَادُهُ ‏.‏\hadithno{2376}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Ka'b bin Malik Al-Ansari narrated from his father, that the Messenger of Allah (s.a.w) said:"Two wolves free among sheep are no more destructive to them than a man's desire for wealth and honor is to his religion}}
\hadithdefcmd{tirmidhi}{2377}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، أَخْبَرَنِي الْمَسْعُودِيُّ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ نَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى حَصِيرٍ فَقَامَ وَقَدْ أَثَّرَ فِي جَنْبِهِ فَقُلْنَا يَا رَسُولَ اللَّهِ لَوِ اتَّخَذْنَا لَكَ وِطَاءً ‏.‏ فَقَالَ ‏ "‏ مَا لِي وَمَا لِلدُّنْيَا مَا أَنَا فِي الدُّنْيَا إِلاَّ كَرَاكِبٍ اسْتَظَلَّ تَحْتَ شَجَرَةٍ ثُمَّ رَاحَ وَتَرَكَهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2377}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah narrated :"The Messenger of Allah (s.a.w) was sleeping upon a mat, then he stood, and the mat had left marks on his side. We said: 'O Messenger of Allah! We said: 'O Messenger of Allah! We could get a bed for you.' He said: 'What do I have to do with the world! I am not in the world but as a rider seeking shade under a tree, then he catches his breath and leaves it}}
\hadithdefcmd{tirmidhi}{2378}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، وَأَبُو دَاوُدَ قَالاَ حَدَّثَنَا زُهَيْرُ بْنُ مُحَمَّدٍ، حَدَّثَنِي مُوسَى بْنُ وَرْدَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّجُلُ عَلَى دِينِ خَلِيلِهِ فَلْيَنْظُرْ أَحَدُكُمْ مَنْ يُخَالِلُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2378}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"A man is upon the religion of his friend, so let one of you look at whom he befriends}}
\hadithdefcmd{tirmidhi}{2379}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، هُوَ ابْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ الأَنْصَارِيُّ قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَتْبَعُ الْمَيِّتَ ثَلاَثٌ فَيَرْجِعُ اثْنَانِ وَيَبْقَى وَاحِدٌ يَتْبَعُهُ أَهْلُهُ وَمَالُهُ وَعَمَلُهُ فَيَرْجِعُ أَهْلُهُ وَمَالُهُ وَيَبْقَى عَمَلُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2379}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (S.a.w) said:"Three follow the deceased, two of them return, and one remains. He is followed by his family, his wealth, and his deeds. So his family and his wealth returns, and his deeds remain}}
\hadithdefcmd{tirmidhi}{2380}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي أَبُو سَلَمَةَ الْحِمْصِيُّ، وَحَبِيبُ بْنُ صَالِحٍ، عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ، عَنْ مِقْدَامِ بْنِ مَعْدِيكَرِبَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مَلأَ آدَمِيٌّ وِعَاءً شَرًّا مِنْ بَطْنٍ بِحَسْبِ ابْنِ آدَمَ أُكُلاَتٌ يُقِمْنَ صُلْبَهُ فَإِنْ كَانَ لاَ مَحَالَةَ فَثُلُثٌ لِطَعَامِهِ وَثُلُثٌ لِشَرَابِهِ وَثُلُثٌ لِنَفَسِهِ ‏"‏ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، نَحْوَهُ ‏.‏ وَقَالَ الْمِقْدَامُ بْنُ مَعْدِيكَرِبَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2380}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Miqdam bin Ma'dikarib said:"I heard the Messenger of Allah (S.a.w) saying: 'The human does not fill any container that is worse than his stomach. It is sufficient for the son of Adam to eat what will support his back. If this is not possible, then a third for food, a third for drink, and third for his breath}}
\hadithdefcmd{tirmidhi}{2381}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ شَيْبَانَ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يُرَائِي يُرَائِي اللَّهُ بِهِ وَمَنْ يُسَمِّعْ يُسَمِّعِ اللَّهُ بِهِ ‏"‏ ‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لاَ يَرْحَمُ النَّاسَ لاَ يَرْحَمُهُ اللَّهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جُنْدَبٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2381}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed narrated that the Messenger of Allah (S.a.w) said:"Whoever wants to be seen, Allah will show him, And whoever wants to be heard of, Allah will make him heard off." And he narrated that the Messenger of Allah (s.a.w) said: "He who shows no mercy to the people, Allah shows him no mercy}}
\hadithdefcmd{tirmidhi}{2382}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا حَيْوَةُ بْنُ شُرَيْحٍ، أَخْبَرَنِي الْوَلِيدُ بْنُ أَبِي الْوَلِيدِ أَبُو عُثْمَانَ الْمَدَنِيُّ، أَنَّ عُقْبَةَ بْنَ مُسْلِمٍ، حَدَّثَهُ أَنَّ شُفَيًّا الأَصْبَحِيَّ حَدَّثَهُ أَنَّهُ، دَخَلَ الْمَدِينَةَ فَإِذَا هُوَ بِرَجُلٍ قَدِ اجْتَمَعَ عَلَيْهِ النَّاسُ فَقَالَ مَنْ هَذَا فَقَالُوا أَبُو هُرَيْرَةَ ‏.‏ فَدَنَوْتُ مِنْهُ حَتَّى قَعَدْتُ بَيْنَ يَدَيْهِ وَهُوَ يُحَدِّثُ النَّاسَ فَلَمَّا سَكَتَ وَخَلاَ قُلْتُ لَهُ أَنْشُدُكَ بِحَقٍّ وَبِحَقٍّ لَمَا حَدَّثْتَنِي حَدِيثًا سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَقَلْتَهُ وَعَلِمْتَهُ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ أَفْعَلُ لأُحَدِّثَنَّكَ حَدِيثًا حَدَّثَنِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم عَقَلْتُهُ وَعَلِمْتُهُ ‏.‏ ثُمَّ نَشَغَ أَبُو هُرَيْرَةَ نَشْغَةً فَمَكَثَ قَلِيلاً ثُمَّ أَفَاقَ فَقَالَ لأُحَدِّثَنَّكَ حَدِيثًا حَدَّثَنِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْبَيْتِ مَا مَعَنَا أَحَدٌ غَيْرِي وَغَيْرُهُ ‏.‏ ثُمَّ نَشَغَ أَبُو هُرَيْرَةَ نَشْغَةً أُخْرَى ثُمَّ أَفَاقَ فَمَسَحَ وَجْهَهُ فَقَالَ لأُحَدِّثَنَّكَ حَدِيثًا حَدَّثَنِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا وَهُوَ فِي هَذَا الْبَيْتِ مَا مَعَنَا أَحَدٌ غَيْرِي وَغَيْرُهُ ‏.‏ ثُمَّ نَشَغَ أَبُو هُرَيْرَةَ نَشْغَةً أُخْرَى ثُمَّ أَفَاقَ وَمَسَحَ وَجْهَهُ فَقَالَ أَفْعَلُ لأُحَدِّثَنَّكَ حَدِيثًا حَدَّثَنِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ فِي هَذَا الْبَيْتِ مَا مَعَهُ أَحَدٌ غَيْرِي وَغَيْرُهُ ‏.‏ ثُمَّ نَشَغَ أَبُو هُرَيْرَةَ نَشْغَةً شَدِيدَةً ثُمَّ مَالَ خَارًّا عَلَى وَجْهِهِ فَأَسْنَدْتُهُ عَلَىَّ طَوِيلاً ثُمَّ أَفَاقَ فَقَالَ حَدَّثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى إِذَا كَانَ يَوْمُ الْقِيَامَةِ يَنْزِلُ إِلَى الْعِبَادِ لِيَقْضِيَ بَيْنَهُمْ وَكُلُّ أُمَّةٍ جَاثِيَةٌ فَأَوَّلُ مَنْ يَدْعُو بِهِ رَجُلٌ جَمَعَ الْقُرْآنَ وَرَجُلٌ قُتِلَ فِي سَبِيلِ اللَّهِ وَرَجُلٌ كَثِيرُ الْمَالِ فَيَقُولُ اللَّهُ لِلْقَارِئِ أَلَمْ أُعَلِّمْكَ مَا أَنْزَلْتُ عَلَى رَسُولِي قَالَ بَلَى يَا رَبِّ ‏.‏ قَالَ فَمَاذَا عَمِلْتَ فِيمَا عُلِّمْتَ قَالَ كُنْتُ أَقُومُ بِهِ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ ‏.‏ فَيَقُولُ اللَّهُ لَهُ كَذَبْتَ وَتَقُولُ لَهُ الْمَلاَئِكَةُ كَذَبْتَ وَيَقُولُ اللَّهُ لَهُ بَلْ أَرَدْتَ أَنْ يُقَالَ إِنَّ فُلاَنًا قَارِئٌ فَقَدْ قِيلَ ذَاكَ ‏.‏ وَيُؤْتَى بِصَاحِبِ الْمَالِ فَيَقُولُ اللَّهُ لَهُ أَلَمْ أُوَسِّعْ عَلَيْكَ حَتَّى لَمْ أَدَعْكَ تَحْتَاجُ إِلَى أَحَدٍ قَالَ بَلَى يَا رَبِّ ‏.‏ قَالَ فَمَاذَا عَمِلْتَ فِيمَا آتَيْتُكَ قَالَ كُنْتُ أَصِلُ الرَّحِمَ وَأَتَصَدَّقُ ‏.‏ فَيَقُولُ اللَّهُ لَهُ كَذَبْتَ وَتَقُولُ لَهُ الْمَلاَئِكَةُ كَذَبْتَ وَيَقُولُ اللَّهُ تَعَالَى بَلْ أَرَدْتَ أَنْ يُقَالَ فُلاَنٌ جَوَادٌ فَقَدْ قِيلَ ذَاكَ ‏.‏ وَيُؤْتَى بِالَّذِي قُتِلَ فِي سَبِيلِ اللَّهِ فَيَقُولُ اللَّهُ لَهُ فِي مَاذَا قُتِلْتَ فَيَقُولُ أُمِرْتُ بِالْجِهَادِ فِي سَبِيلِكَ فَقَاتَلْتُ حَتَّى قُتِلْتُ ‏.‏ فَيَقُولُ اللَّهُ تَعَالَى لَهُ كَذَبْتَ وَتَقُولُ لَهُ الْمَلاَئِكَةُ كَذَبْتَ وَيَقُولُ اللَّهُ بَلْ أَرَدْتَ أَنْ يُقَالَ فُلاَنٌ جَرِيءٌ فَقَدْ قِيلَ ذَاكَ ‏"‏ ‏.‏ ثُمَّ ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رُكْبَتِي فَقَالَ ‏"‏ يَا أَبَا هُرَيْرَةَ أُولَئِكَ الثَّلاَثَةُ أَوَّلُ خَلْقِ اللَّهِ تُسَعَّرُ بِهِمُ النَّارُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَقَالَ الْوَلِيدُ أَبُو عُثْمَانَ فَأَخْبَرَنِي عُقْبَةُ بْنُ مُسْلِمٍ أَنَّ شُفَيًّا هُوَ الَّذِي دَخَلَ عَلَى مُعَاوِيَةَ فَأَخْبَرَهُ بِهَذَا ‏.‏ قَالَ أَبُو عُثْمَانَ وَحَدَّثَنِي الْعَلاَءُ بْنُ أَبِي حَكِيمٍ أَنَّهُ كَانَ سَيَّافًا لِمُعَاوِيَةَ فَدَخَلَ عَلَيْهِ رَجُلٌ فَأَخْبَرَهُ بِهَذَا عَنْ أَبِي هُرَيْرَةَ فَقَالَ مُعَاوِيَةُ قَدْ فُعِلَ بِهَؤُلاَءِ هَذَا فَكَيْفَ بِمَنْ بَقِيَ مِنَ النَّاسِ ثُمَّ بَكَى مُعَاوِيَةُ بُكَاءً شَدِيدًا حَتَّى ظَنَنَّا أَنَّهُ هَالِكٌ وَقُلْنَا قَدْ جَاءَنَا هَذَا الرَّجُلُ بِشَرٍّ ثُمَّ أَفَاقَ مُعَاوِيَةُ وَمَسَحَ عَنْ وَجْهِهِ وَقَالَ صَدَقَ اللَّهُ وَرَسُولُهُْ ‏:‏ ‏(‏مَنْ كَانَ يُرِيدُ الْحَيَاةَ الدُّنْيَا وَزِينَتَهَا نُوَفِّ إِلَيْهِمْ أَعْمَالَهُمْ فِيهَا وَهُمْ فِيهَا لاَ يُبْخَسُونَ * أُولَئِكَ الَّذِينَ لَيْسَ لَهُمْ فِي الآخِرَةِ إِلاَّ النَّارُ وَحَبِطَ مَا صَنَعُوا فِيهَا وَبَاطِلٌ مَا كَانُوا يَعْمَلُونَ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2382}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Walid bin Abi Al-Wald abu 'Utthman Al-Mada'ini narrated that 'Uqbah bin Muslim narrated to him, that shufaiy Al-Asbahi narrated that he entered Al-Madinah and saw a man around whom the people had gathered. He asked:" Who is this?" They said: "Abu Hurairah." (He said):So I got close to him until I was sitting in front of him as he was narrating to the people. When he was silent and alone, I said to him: " I ask youabsolute truth if you would narrate to me a Hadith which you heard from the Messenger of Allah (s.a.w), That you understand and know." So Abu Hurairah said: "You want me to narrate a Hadith to you which the Messenger of Allah (s.a.w) narrated to me that I understand and know." Then Abu Hurairah began sobbing profusely. We sat for a while, then he recovered and said: "I shall narrate to you a Hadith which the Messenger of Allah (s.a.w) narrated in this House, while there was no one with us other than he and I." Then, again, Abu Hurairah began sobbing severely. Then he recovered, and wiped his face, and said: "you want me to narrate to you a Hadith which the Messenger of Allah (s.a.w) narrated while he and I were sitting in this House, and no one was with us but he and I." Then Abu Hurairah began sobbing severely. Then he bent, falling on his face, so I supported him for a long time. Then he recovered and said: "The Messenger of Allah narrated to me that on the Day of Judgement, Allah, Most High, will descend to His slaves t judge between them. Every nation shall be kneeling. The first of those who will be called before him will be a man who memorized the Qur'an, and a man who was killed in Allah's cause, and a wealthy man. Allah will say to the reciter: 'Did I not teach you what I revealed to My Messenger?" He says: 'Of course O Lord!' He says: 'Then what did you do with what you learned?' He said: 'I would stand (in prayer reciting) with it during all hours of the night and all hours of the day.' Then Allah would say to him: 'You have lied.' And the angels will say: 'You have lied.'Allah will say to him: 'Rather, you wanted it to be said that so-and-so is a reciter. And that was said.' The person with the wealth will be brought, and Allah will say to him: 'Was I not so generous with you, such that I did not leave you having any need from anyone?' He will say: 'Of course O Lord!' He says: 'Then what did you do with what I gave to you?' He says: 'I would nurture the ties of kinship and give charity.' Then Allah will say to him: 'You have lied.' And the angels will say to him: 'You have lied.' Allah, Most High, will say: 'Rather, you wanted it to be said that so-and-so is so generous, and that was said.' Then the one who was killed in Allah's cause shall be brought, and Allah will say to him : 'For what were you killed?' So he says: 'I was commanded to fight in Your cause ,so I fought until I was killed.' Allah [Most High] will say to him: 'You have lied.' And the angels will say to him: 'You have lied.' Allah [Most High] will say: 'Rather, you wanted it be said that so-and-so is brave, and that was said.' "Then the Messenger of Allah (s.a.w)hit me on my knees and said: 'O Abu Hurairah! These first three are the creatures of Allah with whom the fire will be enflamed on the Day of Judgement.'" Al-Walid Abu 'Uthman Al-Mada'ini said: "So 'Uqbah bin Muslim informed me that Shaufaiy, is the one who entered upon Mu'awiyah to inform him about this." Abu Uthman said: 'This has been done with these people, then how about with those who remain among the people?" Then Mu'awiyah begin weeping so intensely, that we thought that he will kill himself with excessive weeping. We said: "This man came to us to cause evil." Then Mu'awiyah recovered, wiped off his face and said: "Allah and His Messenger told the truth: Whosoever desires the life of the world and its glitter, then we shall pay in full (the wages of) their deeds therein, and they shall have no diminution therein. They are those for whom there is nothing in the Hereafter Fire, and vain are the deeds they did therein. And of no effect is that which they used to do}}
\hadithdefcmd{tirmidhi}{2383}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنِي الْمُحَارِبِيُّ، عَنْ عَمَّارِ بْنِ سَيْفٍ الضَّبِّيِّ، عَنْ أَبِي مُعَانٍ الْبَصْرِيِّ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَعَوَّذُوا بِاللَّهِ مِنْ جُبِّ الْحُزْنِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا جُبُّ الْحُزْنِ قَالَ ‏"‏ وَادٍ فِي جَهَنَّمَ تَتَعَوَّذُ مِنْهُ جَهَنَّمُ كُلَّ يَوْمٍ مِائَةَ مَرَّةٍ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَنْ يَدْخُلُهُ قَالَ ‏"‏ الْقُرَّاءُ الْمُرَاءُونَ بِأَعْمَالِهِمْ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ\hadithno{2383}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Seek refuge in Allah from the Pit of Sorrows." They said: "O Messenger of Allah! What is the Pit of Sorrows?" He said: "gorge in Hell from which Hell seeks Allah's refuge a Hundred times every day." It was said: "O Messenger of Allah! Who shall enter it?" He said: "The reciters who were showing off with their deeds}}
\hadithdefcmd{tirmidhi}{2384}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا أَبُو سِنَانٍ الشَّيْبَانِيُّ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ الرَّجُلُ يَعْمَلُ الْعَمَلَ فَيُسِرُّهُ فَإِذَا اطُّلِعَ عَلَيْهِ أَعْجَبَهُ ذَلِكَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَهُ أَجْرَانِ أَجْرُ السِّرِّ وَأَجْرُ الْعَلاَنِيَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ الأَعْمَشُ وَغَيْرُهُ عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ عَنْ أَبِي صَالِحٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَأَصْحَابُ الأَعْمَشِ لَمْ يَذْكُرُوا فِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ هَذَا الْحَدِيثَ فَقَالَ إِذَا اطُّلِعَ عَلَيْهِ فَأَعْجَبَهُ فَإِنَّمَا مَعْنَاهُ أَنْ يُعْجِبَهُ ثَنَاءُ النَّاسِ عَلَيْهِ بِالْخَيْرِ لِقَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏ فَيُعْجِبُهُ ثَنَاءُ النَّاسِ عَلَيْهِ لِهَذَا لِمَا يَرْجُو بِثَنَاءِ النَّاسِ عَلَيْهِ فَأَمَّا إِذَا أَعْجَبَهُ لِيَعْلَمَ النَّاسُ مِنْهُ الْخَيْرَ لِيُكْرَمَ عَلَى ذَلِكَ وَيُعَظَّمَ عَلَيْهِ فَهَذَا رِيَاءٌ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا اطُّلِعَ عَلَيْهِ فَأَعْجَبَهُ رَجَاءَ أَنْ يُعْمَلَ بِعَمَلِهِ فَيَكُونَ لَهُ مِثْلُ أُجُورِهِمْ فَهَذَا لَهُ مَذْهَبٌ أَيْضًا ‏.‏\hadithno{2384}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that A man said:"O Messenger of Allah! A man does a deed and conceals it, but when it is discovered that he did it, he is happy about that." He said: " The Messenger of Allah (s.a.w) said: 'He receives two rewards: A reward in its concealment, and a reward in its publicity}}
\hadithdefcmd{tirmidhi}{2385}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَتَى قِيَامُ السَّاعَةِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم إِلَى الصَّلاَةِ فَلَمَّا قَضَى صَلاَتَهُ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنْ قِيَامِ السَّاعَةِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ مَا أَعْدَدْتَ لَهَا ‏"‏ قَالَ يَا رَسُولَ اللَّهِ مَا أَعْدَدْتُ لَهَا كَبِيرَ صَلاَةٍ وَلاَ صَوْمٍ إِلاَّ أَنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ وَأَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ فَمَا رَأَيْتُ فَرِحَ الْمُسْلِمُونَ بَعْدَ الإِسْلاَمِ فَرَحَهُمْ بِهَذَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2385}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that a man came to the Messenger of Allah (s.a.w) and said:" O Messenger of Allah! When will the Hour be established?" So the Propher (s.a.w) stood to perform Salat and when he was finished his Salat he said: "Where is the one who asked when the hour will be established?" The man said: "It was I, O Mesenger of Allah!" He said: "What have you prepared for it?" He said: "O Messenger of allah! I have not prepared very much of salat nor fasting for it, but I love Allah and His Messenger." So the Messenger of Allah(s.a.w) said: "A man shall be with whom ever he loves, and you shall be with whomever you love." So after the advent of Islam, I did not see that anything brought the Muslims more happiness than that}}
\hadithdefcmd{tirmidhi}{2386}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ وَلَهُ مَا اكْتَسَبَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَصَفْوَانَ بْنِ عَسَّالٍ وَأَبِي هُرَيْرَةَ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ الْحَسَنِ الْبَصْرِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2386}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (s.a.w) said:" A man shall be with whoever he loves, and for him shall be what he has earned}}
\hadithdefcmd{tirmidhi}{2387}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ جَاءَ أَعْرَابِيٌّ جَهْوَرِيُّ الصَّوْتِ فَقَالَ يَا مُحَمَّدُ الرَّجُلُ يُحِبُّ الْقَوْمَ وَلَمَّا يَلْحَقْ بِهِمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ مَحْمُودٍ ‏.‏\hadithno{2387}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Safwan bin Assal narrated that a Bedouin with a loud voice and said:" O Muhammad! A man loves the people but does not catch up to them (in deeds)." So the Messenger of Allah(s.a.w) said: "A man shall be with whomever he loves}}
\hadithdefcmd{tirmidhi}{2388}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ أَنَا عِنْدَ ظَنِّ عَبْدِي فِيَّ وَأَنَا مَعَهُ إِذَا دَعَانِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2388}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Indeed Allah Most High says: 'I am as My slave thinks of Me, and I am with him when He calls upon Me}}
\hadithdefcmd{tirmidhi}{2389}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيُّ، عَنْ أَبِيهِ، عَنِ النَّوَّاسِ بْنِ سَمْعَانَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْبِرِّ وَالإِثْمِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْبِرُّ حُسْنُ الْخُلُقِ وَالإِثْمُ مَا حَاكَ فِي نَفْسِكَ وَكَرِهْتَ أَنْ يَطَّلِعَ عَلَيْهِ النَّاسُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، نَحْوَهُ إِلاَّ أَنَّهُ قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2389}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{An-Nawas bin Sama'an narrated that a man came asking the Messenger of Allah (s.a.w) about righteousness and sin. So the Prophet (s.a.w) said:"Righteouness is good behaviour, and sin is what fluctuates in your chest, and you would hate that the people discovered it about you}}
\hadithdefcmd{tirmidhi}{2390}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي مَرْزُوقٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ أَبِي مُسْلِمٍ الْخَوْلاَنِيِّ، حَدَّثَنِي مُعَاذُ بْنُ جَبَلٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ الْمُتَحَابُّونَ فِي جَلاَلِي لَهُمْ مَنَابِرُ مِنْ نُورٍ يَغْبِطُهُمُ النَّبِيُّونَ وَالشُّهَدَاءُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي الدَّرْدَاءِ وَابْنِ مَسْعُودٍ وَعُبَادَةَ بْنِ الصَّامِتِ وَأَبِي هُرَيْرَةَ وَأَبِي مَالِكٍ الأَشْعَرِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو مُسْلِمٍ الْخَوْلاَنِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ ثُوَبَ ‏.‏\hadithno{2390}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Mu'adh binJabal narrated that the Messenger of Allah (s.a.w) said:"Allah, the Mighty and Sublime, said: 'Those who love each other for the sake of My Majesty shall be upon podiums of light, and they will be admired by the Prophets and the martyrs}}
\hadithdefcmd{tirmidhi}{2391}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَوْ عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ فِي ظِلِّهِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ إِمَامٌ عَادِلٌ وَشَابٌّ نَشَأَ بِعِبَادَةِ اللَّهِ وَرَجُلٌ كَانَ قَلْبُهُ مُعَلَّقًا بِالْمَسْجِدِ إِذَا خَرَجَ مِنْهُ حَتَّى يَعُودَ إِلَيْهِ وَرَجُلاَنِ تَحَابَّا فِي اللَّهِ فَاجْتَمَعَا عَلَى ذَلِكَ وَتَفَرَّقَا وَرَجُلٌ ذَكَرَ اللَّهَ خَالِيًا فَفَاضَتْ عَيْنَاهُ وَرَجُلٌ دَعَتْهُ امْرَأَةٌ ذَاتُ حَسَبٍ وَجَمَالٍ فَقَالَ إِنِّي أَخَافُ اللَّهَ وَرَجُلٌ تَصَدَّقَ بِصَدَقَةٍ فَأَخْفَاهَا حَتَّى لاَ تَعْلَمَ شِمَالُهُ مَا تُنْفِقُ يَمِينُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رُوِيَ هَذَا الْحَدِيثُ عَنْ مَالِكِ بْنِ أَنَسٍ مِنْ غَيْرِ وَجْهٍ مِثْلَ هَذَا وَشَكَّ فِيهِ وَقَالَ عَنْ أَبِي هُرَيْرَةَ أَوْ عَنْ أَبِي سَعِيدٍ وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ رَوَاهُ عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ وَلَمْ يَشُكَّ فِيهِ يَقُولُ عَنْ أَبِي هُرَيْرَةَ ‏.‏ حَدَّثَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ الْعَنْبَرِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، حَدَّثَنِي خُبَيْبٌ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ مَالِكِ بْنِ أَنَسٍ بِمَعْنَاهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ كَانَ قَلْبُهُ مُعَلَّقًا بِالْمَسَاجِدِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ ذَاتُ مَنْصِبٍ وَجَمَالٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2391}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Hafs bin 'Asim narrated from Abu Hurairah or Abu Sa'eed that the Messenger of Allah (s.a.w) said:"Seven shall be shaded by Allah under his shade on a day in which there is no shade except His Shade: A just Imam, a young person raised upon worshiping Allah, a man whose heart is attached to the Masjid when he leaves from it until he returns from it, two men who love each other for Allah's sake, coming together upon that, and parting upon that, a man who remembers Allah in privacy and his eyes swell with tears, a man invited by a woman of status and beauty, but he says: 'I fear Allah, Mighty and Sublime is He,' and a man who conceals the charity he gives such that his left hand does not know what his right hand has spent}}
\hadithdefcmd{tirmidhi}{2392}{\hadithno{2392}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{2393}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، قَالَ قَامَ رَجُلٌ فَأَثْنَى عَلَى أَمِيرٍ مِنَ الأُمَرَاءِ فَجَعَلَ الْمِقْدَادُ يَحْثُو فِي وَجْهِهِ التُّرَابَ وَقَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَحْثُوَ فِي وُجُوهِ الْمَدَّاحِينَ التُّرَابَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى زَائِدَةُ عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ عَنْ مُجَاهِدٍ عَنِ ابْنِ عَبَّاسٍ وَحَدِيثُ مُجَاهِدٍ عَنْ أَبِي مَعْمَرٍ أَصَحُّ ‏.‏ وَأَبُو مَعْمَرٍ اسْمُهُ عَبْدُ اللَّهِ بْنُ سَخْبَرَةَ وَالْمِقْدَادُ بْنُ الأَسْوَدِ هُوَ الْمِقْدَادُ بْنُ عَمْرٍو الْكِنْدِيُّ وَيُكْنَى أَبَا مَعْبَدٍ وَإِنَّمَا نُسِبَ إِلَى الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ لأَنَّهُ كَانَ قَدْ تَبَنَّاهُ وَهُوَ صَغِيرٌ ‏.‏\hadithno{2393}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Ma'mar said:"A man stood and praised one of the 'Amirs so Al-Miqdad bin Al-Aswad threw dust in his face and said: 'The Messenger of Allah (s.a.w) ordered us to throw dust in the faces of those who praise others}}
\hadithdefcmd{tirmidhi}{2394}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الْكُوفِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ سَالِمٍ الْخَيَّاطِ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَحْثُوَ فِي أَفْوَاهِ الْمَدَّاحِينَ التُّرَابَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2394}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah(s.a.w) ordered us to throw dut in the mouths of those who praise others}}
\hadithdefcmd{tirmidhi}{2395}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، حَدَّثَنِي سَالِمُ بْنُ غَيْلاَنَ، أَنَّ الْوَلِيدَ بْنَ قَيْسٍ التُّجِيبِيَّ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ سَالِمٌ أَوْ عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، - أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُصَاحِبْ إِلاَّ مُؤْمِنًا وَلاَ يَأْكُلْ طَعَامَكَ إِلاَّ تَقِيٌّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2395}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Sa'eed narrated that the Messenger of Allah(s.a.w) said:"Do not accompany except a believer, and do not serve your food except to one with Taqwa}}
\hadithdefcmd{tirmidhi}{2396}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَرَادَ اللَّهُ بِعَبْدِهِ الْخَيْرَ عَجَّلَ لَهُ الْعُقُوبَةَ فِي الدُّنْيَا وَإِذَا أَرَادَ اللَّهُ بِعَبْدِهِ الشَّرَّ أَمْسَكَ عَنْهُ بِذَنْبِهِ حَتَّى يُوَفَّى بِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ عِظَمَ الْجَزَاءِ مَعَ عِظَمِ الْبَلاَءِ وَإِنَّ اللَّهَ إِذَا أَحَبَّ قَوْمًا ابْتَلاَهُمْ فَمَنْ رَضِيَ فَلَهُ الرِّضَا وَمَنْ سَخِطَ فَلَهُ السَّخَطُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2396}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that the Messenger of Allah (ﷺ) said:"When Allah wants good for his slave, He hastens his punishment in the world. And when He wants bad for His slave, He withholds his sins from him until he appears before Him on the Day of Judgement." And with this (same) chain, (it was reported) from the Prophet (ﷺ) who said: "Indeed greater reward comes with greater trial. And indeed, when Allah loves a people He subjects them to trials, so whoever is content, then for him is pleasure, and whoever is discontent, then for him is wrath}}
\hadithdefcmd{tirmidhi}{2397}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ قَالَتْ عَائِشَةُ مَا رَأَيْتُ الْوَجَعَ عَلَى أَحَدٍ أَشَدَّ مِنْهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2397}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah said:"I have not seen ailment effecting anyone worse than upon the Messenger of Allah (s.a.w)}}
\hadithdefcmd{tirmidhi}{2398}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ أَشَدُّ بَلاَءً قَالَ ‏ "‏ الأَنْبِيَاءُ ثُمَّ الأَمْثَلُ فَالأَمْثَلُ فَيُبْتَلَى الرَّجُلُ عَلَى حَسَبِ دِينِهِ فَإِنْ كَانَ دِينُهُ صُلْبًا اشْتَدَّ بَلاَؤُهُ وَإِنْ كَانَ فِي دِينِهِ رِقَّةٌ ابْتُلِيَ عَلَى حَسَبِ دِينِهِ فَمَا يَبْرَحُ الْبَلاَءُ بِالْعَبْدِ حَتَّى يَتْرُكَهُ يَمْشِي عَلَى الأَرْضِ مَا عَلَيْهِ خَطِيئَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأُخْتِ حُذَيْفَةَ بْنِ الْيَمَانِ ‏أَنَّ النَّبِيَّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ سُئِلَ أَيُّ النَّاسِ أَشَدُّ بَلَاءً قَالَ الْأَنْبِيَاءُ ثُمَّ الْأَمْثَلُ فَالْأَمْثَلُ\hadithno{2398}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Mus'ab bin Sa'd narrated from his father that a man said:"O Messenger of Allah(s.a.w)! Which of the people is tried most severely?" He said: "The Prophets, then those nearest to them, then those nearest to them. A man is tried according to his religion; if he is firm in his religion, then his trials are more severe, and if he is frail in his religion, then he is tried according to the strength of his religion. The servant shall continue to be tried until he is left walking upon the earth without any sins}}
\hadithdefcmd{tirmidhi}{2399}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَزَالُ الْبَلاَءُ بِالْمُؤْمِنِ وَالْمُؤْمِنَةِ فِي نَفْسِهِ وَوَلَدِهِ وَمَالِهِ حَتَّى يَلْقَى اللَّهَ وَمَا عَلَيْهِ خَطِيئَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2399}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"Trials will not cease afflicting the believing man and the believing woman in their self, children, and wealth, until they meet Allah without having any sin}}
\hadithdefcmd{tirmidhi}{2400}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو ظِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ إِذَا أَخَذْتُ كَرِيمَتَىْ عَبْدِي فِي الدُّنْيَا لَمْ يَكُنْ لَهُ جَزَاءٌ عِنْدِي إِلاَّ الْجَنَّةَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَزَيْدِ بْنِ أَرْقَمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو ظِلاَلٍ اسْمُهُ هِلاَلٌ ‏.‏\hadithno{2400}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah(s.a.w) said:"Indeed Allah [Most High] said: 'When I take My slave's sight in the world, then there shall be no reward for him with Me except Paradise}}
\hadithdefcmd{tirmidhi}{2401}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ مَنْ أَذْهَبْتُ حَبِيبَتَيْهِ فَصَبَرَ وَاحْتَسَبَ لَمْ أَرْضَ لَهُ ثَوَابًا دُونَ الْجَنَّةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عِرْبَاضِ بْنِ سَارِيَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2401}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah (narrated from) the Prophet(s.a.w) who said:"Allah, Mighty and Sublime is He, said: 'For whomever I take his sight, and he is patient and seeking a reward, I shall not be satisfied with any reward for him less than Paradise}}
\hadithdefcmd{tirmidhi}{2402}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، وَيُوسُفُ بْنُ مُوسَى الْقَطَّانُ الْبَغْدَادِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَغْرَاءَ أَبُو زُهَيْرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَوَدُّ أَهْلُ الْعَافِيَةِ يَوْمَ الْقِيَامَةِ حِينَ يُعْطَى أَهْلُ الْبَلاَءِ الثَّوَابَ لَوْ أَنَّ جُلُودَهُمْ كَانَتْ قُرِضَتْ فِي الدُّنْيَا بِالْمَقَارِيضِ ‏"‏ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ بِهَذَا الإِسْنَادِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ عَنْ مَسْرُوقٍ قَوْلَهُ شَيْئًا مِنْ هَذَا ‏.‏\hadithno{2402}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that the Prophet (s.a.w) said:"On the Day of Judgement, when the people who were tried (in this world) are given their rewards, the people who were pardoned (in life), will wish that their skins had been cut off with scissors while they were in the world." This Hadith is Gharib, we do not know of it with this chain except through this route. Some of them have reported something similar to this Hadith from Al-A`mash, from Talhah bin Musarrif from Masruq}}
\hadithdefcmd{tirmidhi}{2403}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا يَحْيَى بْنُ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ أَحَدٍ يَمُوتُ إِلاَّ نَدِمَ ‏"‏ ‏.‏ قَالُوا وَمَا نَدَامَتُهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنْ كَانَ مُحْسِنًا نَدِمَ أَنْ لاَ يَكُونَ ازْدَادَ وَإِنْ كَانَ مُسِيئًا نَدِمَ أَنْ لاَ يَكُونَ نَزَعَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏ وَيَحْيَى بْنُ عُبَيْدِ اللَّهِ قَدْ تَكَلَّمَ فِيهِ شُعْبَةُ وَهُوَ يَحْيَى بْنُ عُبَيْدِ اللَّهِ بْنِ مَوْهَبٍ مَدَنِيٌّ ‏.‏\hadithno{2403}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet(s.a.w) said:"There is no one who dies but he shall regret." They said: "What shall he regret over O Messenger of Allah?" He said: "If he was a good doer, he regrets that he did not do more, and if he was an evil doer, he regrets that he did not stop}}
\hadithdefcmd{tirmidhi}{2404}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا يَحْيَى بْنُ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَخْرُجُ فِي آخِرِ الزَّمَانِ رِجَالٌ يَخْتِلُونَ الدُّنْيَا بِالدِّينِ يَلْبَسُونَ لِلنَّاسِ جُلُودَ الضَّأْنِ مِنَ اللِّينِ أَلْسِنَتُهُمْ أَحْلَى مِنَ السُّكَّرِ وَقُلُوبُهُمْ قُلُوبُ الذِّئَابِ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَبِي يَغْتَرُّونَ أَمْ عَلَىَّ يَجْتَرِئُونَ فَبِي حَلَفْتُ لأَبْعَثَنَّ عَلَى أُولَئِكَ مِنْهُمْ فِتْنَةً تَدَعُ الْحَلِيمَ مِنْهُمْ حَيْرَانًا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{2404}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah(s.a.w) said:"In the end of time there shall come men who will swindle the world with religion, decieving the people in soft skins of sheep, their tongues are sweeter than sugar and their hearts are the hearts of wolves. Allah [Mighty and Sublime is He] says: 'Is it me you try to delude or is it against me whom you conspire? By Me, I swear to send upon these people,among them, a Fitnah that leaves them utterly devoid of reason}}
\hadithdefcmd{tirmidhi}{2405}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، أَخْبَرَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا حَمْزَةُ بْنُ أَبِي مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى قَالَ لَقَدْ خَلَقْتُ خَلْقًا أَلْسِنَتُهُمْ أَحْلَى مِنَ الْعَسَلِ وَقُلُوبُهُمْ أَمَرُّ مِنَ الصَّبِرِ فَبِي حَلَفْتُ لأُتِيحَنَّهُمْ فِتْنَةً تَدَعُ الْحَلِيمَ مِنْهُمْ حَيْرَانًا فَبِي يَغْتَرُّونَ أَمْ عَلَىَّ يَجْتَرِءُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عُمَرَ لَا نَعْرِفُهُ إِلَّا مِنْ هَذَا الْوَجْهِ\hadithno{2405}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Umar narrated that the Prophet(s.a.w) said:"Indeed Allah, Most High, said:'I have created creatures whose tongues are sweeter than honey and their hearts are more bitter than aloes. So by Me, I swear to abase them with a Fitnah, leaving them utterly devoid of reason. Is it Me whom they try to delude, or it is against Me whom they conspire?}}
\hadithdefcmd{tirmidhi}{2406}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا النَّجَاةُ قَالَ ‏ "‏ أَمْسِكْ عَلَيْكَ لِسَانَكَ وَلْيَسَعْكَ بَيْتُكَ وَابْكِ عَلَى خَطِيئَتِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2406}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Uqbah bin 'Amir narrated:"I said: 'O Messenger of Allah! What is the means to salvation?' He said: 'That you control your tongue, suffice yourself your house, and cry over your sins}}
\hadithdefcmd{tirmidhi}{2407}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي الصَّهْبَاءِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، رَفَعَهُ قَالَ ‏ "‏ إِذَا أَصْبَحَ ابْنُ آدَمَ فَإِنَّ الأَعْضَاءَ كُلَّهَا تُكَفِّرُ اللِّسَانَ فَتَقُولُ اتَّقِ اللَّهَ فِينَا فَإِنَّمَا نَحْنُ بِكَ فَإِنِ اسْتَقَمْتَ اسْتَقَمْنَا وَإِنِ اعْوَجَجْتَ اعْوَجَجْنَا ‏"‏ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ حَمَّادِ بْنِ زَيْدٍ، نَحْوَهُ وَلَمْ يَرْفَعْهُ وَهَذَا أَصَحُّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ مُوسَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ حَمَّادِ بْنِ زَيْدٍ وَلَمْ يَرْفَعُوهُ ‏.‏ حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي الصَّهْبَاءِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَحْسَبُهُ عَنِ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2407}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa'eed Al-Khudri narrated (that the Prophet s.a.w) said:"When the son of Adam wakes up in the morning, all of his body parts bow to the tongue and say: 'Fear Allah regarding us, we are only part of you. If you are straight we are straight and if you are crooked we are crooked}}
\hadithdefcmd{tirmidhi}{2408}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَتَكَفَّلُ لِي مَا بَيْنَ لَحْيَيْهِ وَمَا بَيْنَ رِجْلَيْهِ أَتَكَفَّلُ لَهُ بِالْجَنَّةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَهْلٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ سَهْلِ بْنِ سَعْدٍ ‏.‏\hadithno{2408}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Sahl bin Sa'd narrated that the Messenger of Allah (s.a.w) said:"Whoever guarantees for me what is between his jaws and what is between his legs, I shall guarantee Paradise for him}}
\hadithdefcmd{tirmidhi}{2409}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَقَاهُ اللَّهُ شَرَّ مَا بَيْنَ لَحْيَيْهِ وَشَرَّ مَا بَيْنَ رِجْلَيْهِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى أَبُو حَازِمٍ الَّذِي رَوَى عَنْ أَبِي هُرَيْرَةَ اسْمُهُ سَلْمَانُ مَوْلَى عَزَّةَ الأَشْجَعِيَّةِ وَهُوَ كُوفِيٌّ وَأَبُو حَازِمٍ الَّذِي رَوَى عَنْ سَهْلِ بْنِ سَعْدٍ هُوَ أَبُو حَازِمٍ الزَّاهِدُ مَدَنِيٌّ وَاسْمُهُ سَلَمَةُ بْنُ دِينَارٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2409}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"For whomever Allah protects against the evil of what is between his jaws and the evil of what is between his legs, he shall enter Paradise}}
\hadithdefcmd{tirmidhi}{2410}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَاعِزٍ، عَنْ سُفْيَانَ بْنِ عَبْدِ اللَّهِ الثَّقَفِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ حَدِّثْنِي بِأَمْرٍ أَعْتَصِمُ بِهِ ‏.‏ قَالَ ‏"‏ قُلْ رَبِّيَ اللَّهُ ثُمَّ اسْتَقِمْ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مَا أَخْوَفُ مَا تَخَافُ عَلَىَّ فَأَخَذَ بِلِسَانِ نَفْسِهِ ثُمَّ قَالَ ‏"‏ هَذَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ سُفْيَانَ بْنِ عَبْدِ اللَّهِ الثَّقَفِيِّ ‏.‏\hadithno{2410}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sufyan bin 'Abdullah Ath-Thaqafi said:I said: "O Messenger of Allah! Inform me about a matter that I may hold fast to." He said: 'Say: My Lord is Allah, then be steadfast.' I said: "O Messenger of Allah! What do you fear most for me?" So he took hold of his tongue and said: 'This}}
\hadithdefcmd{tirmidhi}{2411}{حَدَّثَنَا أَبُو عَبْدِ اللَّهِ، مُحَمَّدُ بْنُ أَبِي ثَلْجٍ الْبَغْدَادِيُّ صَاحِبُ أَحْمَدَ بْنِ حَنْبَلٍ حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاطِبٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُكْثِرُوا الْكَلاَمَ بِغَيْرِ ذِكْرِ اللَّهِ فَإِنَّ كَثْرَةَ الْكَلاَمِ بِغَيْرِ ذِكْرِ اللَّهِ قَسْوَةٌ لِلْقَلْبِ وَإِنَّ أَبْعَدَ النَّاسِ مِنَ اللَّهِ الْقَلْبُ الْقَاسِي ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ، حَدَّثَنِي أَبُو النَّضْرِ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حَاطِبٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حَاطِبٍ ‏.‏\hadithno{2411}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah (s.a.w) said:"Do not talk too much without remembrance of Allah. Indeed excessive talking without remembrance of Allah hardens the heart. And indeed the furthest of people from Allah is the harsh-hearted}}
\hadithdefcmd{tirmidhi}{2412}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ بْنِ خُنَيْسٍ الْمَكِّيُّ، قَالَ سَمِعْتُ سَعِيدَ بْنَ حَسَّانَ الْمَخْزُومِيَّ، قَالَ حَدَّثَتْنِي أُمُّ صَالِحٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ أُمِّ حَبِيبَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ كَلاَمِ ابْنِ آدَمَ عَلَيْهِ لاَ لَهُ إِلاَّ أَمْرٌ بِمَعْرُوفٍ أَوْ نَهْىٌ عَنْ مُنْكَرٍ أَوْ ذِكْرُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ يَزِيدَ بْنِ خُنَيْسٍ ‏.‏\hadithno{2412}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm Habibah, the wife of the Prophet (s.a.w), narrated from the Prophet (s.a.w) who said:"The son of Adam's speech is against him not for him, except for commanding good, or forbidding evil, or remembrance of Allah}}
\hadithdefcmd{tirmidhi}{2413}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، حَدَّثَنَا أَبُو الْعُمَيْسِ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ آخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ سَلْمَانَ وَبَيْنَ أَبِي الدَّرْدَاءِ فَزَارَ سَلْمَانُ أَبَا الدَّرْدَاءِ فَرَأَى أُمَّ الدَّرْدَاءِ مُتَبَذِّلَةً فَقَالَ مَا شَأْنُكِ مُتَبَذِّلَةً قَالَتْ إِنَّ أَخَاكَ أَبَا الدَّرْدَاءِ لَيْسَ لَهُ حَاجَةٌ فِي الدُّنْيَا ‏.‏ قَالَ فَلَمَّا جَاءَ أَبُو الدَّرْدَاءِ قَرَّبَ إِلَيْهِ طَعَامًا فَقَالَ كُلْ فَإِنِّي صَائِمٌ ‏.‏ قَالَ مَا أَنَا بِآكِلٍ حَتَّى تَأْكُلَ ‏.‏ قَالَ فَأَكَلَ فَلَمَّا كَانَ اللَّيْلُ ذَهَبَ أَبُو الدَّرْدَاءِ لِيَقُومَ فَقَالَ لَهُ سَلْمَانُ نَمْ ‏.‏ فَنَامَ ثُمَّ ذَهَبَ يَقُومُ فَقَالَ لَهُ نَمْ ‏.‏ فَنَامَ فَلَمَّا كَانَ عِنْدَ الصُّبْحِ قَالَ لَهُ سَلْمَانُ قُمِ الآنَ فَقَامَا فَصَلَّيَا فَقَالَ إِنَّ لِنَفْسِكَ عَلَيْكَ حَقًّا وَلِرَبِّكَ عَلَيْكَ حَقًّا وَلِضَيْفِكَ عَلَيْكَ حَقًّا وَإِنَّ لأَهْلِكَ عَلَيْكَ حَقًّا فَأَعْطِ كُلَّ ذِي حَقٍّ حَقَّهُ ‏.‏ فَأَتَيَا النَّبِيَّ صلى الله عليه وسلم فَذَكَرَا ذَلِكَ فَقَالَ لَهُ ‏ "‏ صَدَقَ سَلْمَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو الْعُمَيْسِ اسْمُهُ عُتْبَةُ بْنُ عَبْدِ اللَّهِ وَهُوَ أَخُو عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ الْمَسْعُودِيِّ ‏.‏\hadithno{2413}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ubu Juhaifah narrated from his father who said:"The Messenger of Allah (s.a.w) made a bond of brotherhood between Salman and Abu Ad-Darda. Salman went to visit Abu Ad-Darda, and saw Umm Ad-Darda wearing shabby clothes, So he said: 'Why are you wearing such shabby clothes?' She said: 'Your brother Abu Ad-Darda has no interest in the world.' So when Abu Ad-Darda arrived, he prepared some food for him (Salman) and said: 'Eat, for I am fasting.' He said: 'I shall not eat until you eat.'" He said: "So he ate. When night came Abu Ad-Darda started to leave and stand (in prayer), but Salman said to him: 'Sleep.' So he slept. Then he went to stand (in prayer) but he said to him: 'Sleep'. So he slept. When the morning (Fajr) came,Salman said: 'Get up now.'So he got up to perform Salat. Then he (Salman) said: 'Indeed your self has a right upon you, your Lord has a right upon you, your guest has a right upon you, and your family has a right upon you. So give each the right they are due. The Prophet (s.a.w), and that was mentioned to him, so he said: 'Salman has told the truth}}
\hadithdefcmd{tirmidhi}{2414}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ عَبْدِ الْوَهَّابِ بْنِ الْوَرْدِ، عَنْ رَجُلٍ، مِنْ أَهْلِ الْمَدِينَةِ قَالَ كَتَبَ مُعَاوِيَةُ إِلَى عَائِشَةَ أُمِّ الْمُؤْمِنِينَ رضى الله عنها أَنِ اكْتُبِي إِلَىَّ كِتَابًا تُوصِينِي فِيهِ وَلاَ تُكْثِرِي عَلَىَّ ‏.‏ فَكَتَبَتْ عَائِشَةُ رضى الله عنها إِلَى مُعَاوِيَةَ سَلاَمٌ عَلَيْكَ أَمَّا بَعْدُ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ الْتَمَسَ رِضَاءَ اللَّهِ بِسَخَطِ النَّاسِ كَفَاهُ اللَّهُ مُؤْنَةَ النَّاسِ وَمَنِ الْتَمَسَ رِضَاءَ النَّاسِ بِسَخَطِ اللَّهِ وَكَلَهُ اللَّهُ إِلَى النَّاسِ ‏"‏ ‏.‏ وَالسَّلاَمُ عَلَيْكَ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا كَتَبَتْ إِلَى مُعَاوِيَةَ فَذَكَرَ الْحَدِيثَ بِمَعْنَاهُ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{2414}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdul-Wahhab bin Al-Ward narrated from a man among the inhabitants of Al-Madinah who said:"Mu'awiyah wrote a letter to 'Aishah, that: 'Write a letter to advise me , and do not overburden me.'" He said: "So 'Aishah [may Allah be pleased with her]wrote to Mu'awiyah: 'Peace be upon you. As for what follows: Indeed I heard the Messenger of Allah (s.a.w) saying: Whoever seeks Allah's pleasure by the people's wrath, Allah will suffice him from the people. And who ever seeks the people's pleasure by Allah's wrath, Allah will entrust him to the people. And Peace be upon you}}
